@@ -18,7 +18,7 @@ You should have received a copy of the GNU General Public License
 along with Cecilia 5.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-import os, sys, wx, time, math, copy, codecs
+import os, sys, wx, time, math, copy, codecs, pdb
 from types import UnicodeType, IntType
 import pprint as pp
 from constants import *
@@ -28,6 +28,19 @@ import unicodedata
 from subprocess import Popen
 from pyolib._wxwidgets import SpectrumDisplay
 
+def buildFileTree():
+    root = MODULES_PATH
+    directories = []
+    files = {}
+    for dir in sorted(os.listdir(MODULES_PATH)):
+        if not dir.startswith('.'):
+            directories.append(dir)
+            files[dir] = []
+            for f in sorted(os.listdir(os.path.join(root, dir))):
+                if not f.startswith('.'):
+                    files[dir].append(f)
+    return root, directories, files
+
 def setVar(var, value):
     vars.CeciliaVar[var] = value
 
@@ -48,23 +61,100 @@ def setJackParams(client = None, inPortName = None, outPortName = None):
 def setPlugins(x, pos):
     vars.CeciliaVar['plugins'][pos] = x
 
-def getDayTime():
-    time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime())
-
 def getControlPanel():
     return getVar('interface').getControlPanel()
 
 def writeVarToDisk():
     vars.writeCeciliaPrefsToFile()
 
+def chooseColour(i, numlines):
+    def clip(x):
+        val = int(x*255)
+        if val < 0: val = 0
+        elif val > 255: val = 255
+        else: val = val
+        return val
+
+    def colour(i, numlines, sat, bright):
+        hue = (i / float(numlines)) * 315
+        segment = math.floor(hue / 60) % 6
+        fraction = hue / 60 - segment
+        t1 = bright * (1 - sat)
+        t2 = bright * (1 - (sat * fraction))
+        t3 = bright * (1 - (sat * (1 - fraction)))
+        if segment == 0:
+            r, g, b = bright, t3, t1
+        elif segment == 1:
+            r, g, b = t2, bright, t1
+        elif segment == 2:
+            r, g, b = t1, bright, t3
+        elif segment == 3:
+            r, g, b = t1, t2, bright
+        elif segment == 4:
+            r, g, b = t3, t1, bright
+        elif segment == 5:
+            r, g, b = bright, t1, t2
+        return wx.Colour(clip(r),clip(g),clip(b))
+
+    lineColour = colour(i, numlines, 1, 1)
+    midColour = colour(i, numlines, .5, .5)
+    knobColour = colour(i, numlines, .8, .5)
+    sliderColour = colour(i, numlines, .5, .75)
+
+    return [lineColour, midColour, knobColour, sliderColour]
+
+def chooseColourFromName(name):
+    def clip(x):
+        val = int(x*255)
+        if val < 0: val = 0
+        elif val > 255: val = 255
+        else: val = val
+        return val
+
+    def colour(name):
+        vals = COLOUR_CLASSES[name]
+        hue = vals[0]
+        bright = vals[1]
+        sat = vals[2]
+        segment = int(math.floor(hue / 60))
+        fraction = hue / 60 - segment
+        t1 = bright * (1 - sat)
+        t2 = bright * (1 - (sat * fraction))
+        t3 = bright * (1 - (sat * (1 - fraction)))
+        if segment == 0:
+            r, g, b = bright, t3, t1
+        elif segment == 1:
+            r, g, b = t2, bright, t1
+        elif segment == 2:
+            r, g, b = t1, bright, t3
+        elif segment == 3:
+            r, g, b = t1, t2, bright
+        elif segment == 4:
+            r, g, b = t3, t1, bright
+        elif segment == 5:
+            r, g, b = bright, t1, t2
+        return wx.Colour(clip(r),clip(g),clip(b))
+
+    lineColour = colour(name)    
+    midColour = colour(name)
+    knobColour = colour(name)
+    sliderColour = colour(name)
+
+    return [lineColour, midColour, knobColour, sliderColour]
+
 ###### Start / Stop / Drivers ######
 def startCeciliaSound(timer=True, rec=False):
     # Check if soundfile is loaded
     for key in getVar("userInputs").keys():
         if getVar("userInputs")[key]['mode'] == 0:
             if not os.path.isfile(getVar("userInputs")[key]['path']):
-                showErrorDialog('"%s", no input sound file!' % getControlPanel().getCfileinFromName(key).label, 'Please load one...')
-                getControlPanel().getCfileinFromName(key).onLoadFile()
+                showErrorDialog('No input sound file!', 'In/Out panel, "%s" has no input sound file, please load one...' % getControlPanel().getCfileinFromName(key).label)
+                ret = getControlPanel().getCfileinFromName(key).onLoadFile()
+                if not ret:
+                    resetControls()
+                    getVar("grapher").toolbar.loadingMsg.SetForegroundColour(TITLE_BACK_COLOUR)
+                    wx.CallAfter(getVar("grapher").toolbar.loadingMsg.Refresh)
+                    return
     getControlPanel().resetMeter()
     if getVar('spectrumFrame') != None:
         try:
@@ -110,11 +200,6 @@ def resetControls():
         if getControlPanel().tmpTotalTime != getVar("totalTime"):
             getControlPanel().setTotalTime(getControlPanel().tmpTotalTime, True)
         wx.CallAfter(getControlPanel().vuMeter.reset)
-    
-def audioServerIsRunning(state):
-    if state == 1:
-        if getVar("interface"):
-            getControlPanel().transportButtons.setPlay(True)
 
 def queryAudioMidiDrivers():
     inputs, inputIndexes, defaultInput, outputs, outputIndexes, defaultOutput, midiInputs, midiInputIndexes, defaultMidiInput = getVar("audioServer").getAvailableAudioMidiDrivers()
@@ -223,7 +308,7 @@ def loadPlayerEditor(app_type):
     
     path = ''
     dlg = wx.FileDialog(None, message="Choose a %s..." % app_type,
-                             defaultDir=os.path.expanduser('~'),
+                             defaultDir=ensureNFD(os.path.expanduser('~')),
                              wildcard=wildcard, style=wx.OPEN)
 
     if dlg.ShowModal() == wx.ID_OK:
@@ -244,8 +329,6 @@ def listenSoundfile(soundfile):
         loadPlayerEditor('soundfile player')
     if os.path.isfile(soundfile):
         app = getVar("soundfilePlayer")
-        #app = slashifyText(getVar("soundfilePlayer"))
-        #soundfile = slashifyText(soundfile)
         if getVar("systemPlatform")  == 'darwin':
             cmd = 'open -a "%s" "%s"' % (app, soundfile)
             Popen(cmd, shell=True)
@@ -267,8 +350,6 @@ def editSoundfile(soundfile):
         loadPlayerEditor('soundfile editor')
     if os.path.isfile(soundfile):
         app = getVar("soundfileEditor")
-        #app = slashifyText(getVar("soundfileEditor"))
-        #soundfile = slashifyText(soundfile)
         if getVar("systemPlatform")  == 'darwin':
             cmd = 'open -a "%s" "%s"' % (app ,soundfile)
             Popen(cmd, shell=True)
@@ -336,12 +417,15 @@ def loadPresetFromDict(preset):
                         for input in getVar("userInputs"):
                             cfilein = getControlPanel().getCfileinFromName(input)
                             cfilein.reset()
+                            cfilein.reinitSamplerFrame()
                 else:
                     if ok:
                         setVar("userInputs", copy.deepcopy(presetData[data]))
                         updateInputsFromDict()
                     else:
-                        pass
+                        for input in getVar("userInputs"):
+                            cfilein = getControlPanel().getCfileinFromName(input)
+                            cfilein.reinitSamplerFrame()
             elif data == 'userSliders':
                 slidersDict = presetData[data]
                 for slider in getVar("userSliders"):
@@ -350,7 +434,7 @@ def loadPresetFromDict(preset):
                 del slidersDict
             elif data == 'plugins':
                 pluginsDict = copy.deepcopy(presetData[data])
-                getControlPanel().setPlugins(pluginsDict)
+                wx.CallAfter(getControlPanel().setPlugins, pluginsDict)
                 del pluginsDict
             elif data == 'userTogglePopups':
                 togDict = presetData[data]
@@ -360,7 +444,13 @@ def loadPresetFromDict(preset):
                 del togDict
             else:
                 continue
-        if presetData.has_key('userGraph'):
+        if preset == "init":
+            for line in getVar("grapher").getPlotter().getData():
+                try:
+                    line.reinit()
+                except:
+                    pass
+        elif presetData.has_key('userGraph'):
             graphDict = presetData['userGraph']
             ends = ['min', 'max']
             for line in graphDict:
@@ -385,6 +475,22 @@ def loadPresetFromDict(preset):
         setVar("currentModule", currentModule)
         getVar("grapher").setTotalTime(getVar("totalTime"))
 
+        wx.CallAfter(againForPluginKnobs, presetData)
+
+### This is a hack to ensure that plugin knob automations are drawn in the grapher.
+### Called within a wx.CallAfter to be executed after wx.CallAfter(getControlPanel().setPlugins).
+def againForPluginKnobs(presetData):
+    if presetData.has_key('userGraph'):
+        graphDict = presetData['userGraph']
+        for line in graphDict:
+            for i, graphLine in enumerate(getVar("grapher").getPlotter().getData()):
+                if line == graphLine.getName():
+                    graphLine.setLineState(copy.deepcopy(graphDict[line]))
+                    break
+        del graphDict
+        getVar("grapher").getPlotter().draw()
+        getVar("grapher").setTotalTime(getVar("totalTime"))
+
 def savePresetToDict(presetName):
     presetDict = dict()
     presetDict['nchnls'] = getVar("nchnls")
@@ -438,9 +544,9 @@ def savePresetToDict(presetName):
         del graphDict
 
     if presetName == "init":
-        setVar("initPreset", presetDict)
+        setVar("initPreset", copy.deepcopy(presetDict))
     else:
-        getVar("presets")[presetName] = presetDict
+        getVar("presets")[presetName] = copy.deepcopy(presetDict)
         setVar("isModified", True)
 
 def completeUserInputsDict():
@@ -621,11 +727,6 @@ def resetWidgetVariables():
    
 def parseInterfaceText():
     interfaceWidgets = getVar("interfaceWidgets")
-    setVar("moduleDescription", '')
-    for widget in interfaceWidgets:
-        if widget['type'] == 'cmodule':
-            setVar("moduleDescription", widget['label'])
-            break
     return interfaceWidgets
 
 def updateNchnlsDevices():
@@ -688,14 +789,6 @@ def interpolateLog(lines, size, listlen, yrange):
     return list
 
 ###### Utility functions #######
-def removeExtraSpace(text):
-    li = text.split(' ')
-    text = ''
-    for ele in li:
-        if ele != '':
-            text += ele + ' '
-    return text
-
 def removeDuplicates(seq):
    result = []
    for item in seq:
@@ -703,23 +796,6 @@ def removeDuplicates(seq):
            result.append(item)
    return result
 
-def convertWindowsPath(path):
-    if getVar("systemPlatform")  == 'win32':
-        # C'est peut-etre ca qui fuck les paths avec accents sous Windows
-        return os.path.normpath(path)
-    else:
-        return path
-
-def slashifyText(text):
-    charsToSlashify = [' ', '(', ')']
-    newText = ''
-    for i in range(len(text)):
-        char = text[i]
-        if char in charsToSlashify:
-            char = '\\' + char
-        newText += char
-    return newText
-
 def autoRename(path, index=0, wrap=False):
     if os.path.exists(path):
         file = ensureNFD(os.path.split(path)[1])
