@@ -28,13 +28,13 @@
 #
 # Oct 15, 2004  Gordon Williams (g_will@cyberus.ca)
 #   - Imported modules given leading underscore to name.
-#   - Added Cursor Line Tracking and User Point Labels. 
+#   - Added Cursor Line Tracking and User Point Labels.
 #   - Demo for Cursor Line Tracking and Point Labels.
 #   - Size of plot preview frame adjusted to show page better.
 #   - Added helper functions PositionUserToScreen and PositionScreenToUser in PlotCanvas.
 #   - Added functions GetClosestPoints (all curves) and GetClosestPoint (only closest curve)
 #       can be in either user coords or screen coords.
-#   
+#
 #
 
 """
@@ -42,8 +42,8 @@ This is a simple light weight plotting module that can be used with
 Boa or easily integrated into your own wxPython application.  The
 emphasis is on small size and fast plotting for large data sets.  It
 has a reasonable number of features to do line and scatter graphs
-easily as well as simple bar graphs.  It is not as sophisticated or 
-as powerful as SciPy Plt or Chaco.  Both of these are great packages 
+easily as well as simple bar graphs.  It is not as sophisticated or
+as powerful as SciPy Plt or Chaco.  Both of these are great packages
 but consume huge amounts of computer resources for simple plots.
 They can be found at http://scipy.com
 
@@ -66,7 +66,7 @@ Major Additions Gordon Williams Feb. 2003 (g_will@cyberus.ca)
     -Doc strings and lots of comments
     -Optimizations for large number of points
     -Legends
-    
+
 Did a lot of work here to speed markers up. Only a factor of 4
 improvement though. Lines are much faster than markers, especially
 filled markers.  Stay away from circles and triangles unless you
@@ -96,36 +96,22 @@ import CeciliaLib
 from Widgets import CECTooltip
 from constants import *
 
-# Needs Numeric or numarray or NumPy
 try:
-    import numpy.oldnumeric as _Numeric
+    import numpy as _Numeric
 except:
-    try:
-        import numarray as _Numeric  #if numarray is used it is renamed Numeric
-    except:
-        try:
-            import Numeric as _Numeric
-        except:
-            msg= """
-            This module requires the Numeric/numarray or NumPy module,
-            which could not be imported.  It probably is not installed
-            (it's not part of the standard Python distribution). See the
-            Numeric Python site (http://numpy.scipy.org) for information on
-            downloading source or binaries."""
-            raise ImportError, "Numeric,numarray or NumPy not found. \n" + msg
+    msg= """
+    This module requires the NumPy module, which could not be imported.  
+    It probably is not installed (it's not part of the standard Python 
+    distribution). See the NumPy Python site (http://www.numpy.org/) 
+    for information on downloading source or binaries."""
+    raise ImportError, "NumPy not found. \n" + msg
 
-
-from constants import FONT_FACE
-#
-# Plotting classes...
-#
 class PolyPoints:
     """Base Class for lines and markers
         - All methods are private.
     """
-
     def __init__(self, points, attr):
-        self._points = _Numeric.array(points).astype(_Numeric.Float64)
+        self._points = _Numeric.array(points).astype(_Numeric.float32)
         self._logscale = (False, False)
         self.currentScale= (1,1)
         self.currentShift= (0,0)
@@ -136,10 +122,10 @@ class PolyPoints:
             if name not in self._attributes.keys():
                 raise KeyError, "Style attribute incorrect. Should be one of %s" % self._attributes.keys()
             self.attributes[name] = value
-        
+
     def setLogScale(self, logscale):
         self._logscale = logscale
-    
+
     def __getattr__(self, name):
         if name == 'points':
             if len(self._points)>0:
@@ -153,7 +139,7 @@ class PolyPoints:
                 return self._points
         else:
             raise AttributeError, name
-            
+
     def log10(self, data, ind):
         data = _Numeric.compress(data[:,ind]>0,data,0)
         data[:,ind] = _Numeric.log10(data[:,ind])
@@ -180,7 +166,7 @@ class PolyPoints:
             self.currentScale= scale
             self.currentShift= shift
         # else unchanged use the current scaling
-        
+
     def getLegend(self):
         return self.attributes['legend']
 
@@ -206,12 +192,12 @@ class PolyPoints:
         pntIndex = _Numeric.argmin(d)
         dist = d[pntIndex]
         return [pntIndex, self.points[pntIndex], self.scaled[pntIndex], dist]
-            
+
 class PolyLine(PolyPoints):
     """Class to define line type and style
         - All methods except __init__ are private.
     """
-    
+
     _attributes = {'colour': 'black',
                    'width': 1,
                    'style': wx.SOLID,
@@ -229,7 +215,7 @@ class PolyLine(PolyPoints):
         """
         PolyPoints.__init__(self, points, attr)
 
-    def draw(self, dc, printerScale, coord= None):
+    def draw(self, gc, printerScale, coord= None):
         colour = self.attributes['colour']
         width = self.attributes['width'] * printerScale
         style= self.attributes['style']
@@ -237,14 +223,12 @@ class PolyLine(PolyPoints):
             colour = wx.NamedColour(colour)
         pen = wx.Pen(colour, width, style)
         pen.SetCap(wx.CAP_BUTT)
-        dc.SetPen(pen)
+        gc.SetPen(pen)
         if coord == None:
-            # dc.DrawLines(self.scaled)
-            pts = self.scaled
-            pts = [(pts[i][0], pts[i][1], pts[i+1][0], pts[i+1][1]) for i in range(len(pts)-1)]
-            dc.DrawLineList(pts)
+            if len(self.scaled) >= 2:
+                gc.DrawLines(self.scaled)
         else:
-            dc.DrawLines(coord) # draw legend line
+            gc.DrawLines(coord) # draw legend line
 
     def getSymExtent(self, printerScale):
         """Width and Height of Marker"""
@@ -269,12 +253,12 @@ def GetCircleBitmap(w=6, h=6, fillcol="#000000", pencol="#000000"):
     dc.SelectObject(wx.NullBitmap)
     b.SetMaskColour(maskColour)
     return b
-    
+
 class PolyMarker(PolyPoints):
     """Class to define marker type and style
         - All methods except __init__ are private.
     """
-  
+
     _attributes = {'colour': 'black',
                    'width': 1,
                    'size': 2,
@@ -295,7 +279,7 @@ class PolyMarker(PolyPoints):
                 'fillstyle'= wx.SOLID,      - wx.Brush fill style (use wx.TRANSPARENT for no fill)
                 'marker'= 'circle'          - Marker shape
                 'legend'= ''                - Marker Legend to display
-              
+
             Marker Shapes:
                 - 'circle'
                 - 'dot'
@@ -306,13 +290,14 @@ class PolyMarker(PolyPoints):
                 - 'plus'
                 - 'bmp' ---> Cecilia 5 grapher marker
                 - 'bmpsel' ---> Cecilia 5 grapher selected marker
+                - 'none' ---> Cecilia 5 grapher non selected lines
         """
-      
+
         PolyPoints.__init__(self, points, attr)
         self.circleBitmap = GetCircleBitmap(6, 6, "#000000", "#000000")
         self.circleBitmapSel = GetCircleBitmap(8, 8, "#EEEEEE", "#000000")
 
-    def draw(self, dc, printerScale, coord= None):
+    def draw(self, gc, printerScale, coord= None):
         colour = self.attributes['colour']
         width = self.attributes['width'] * printerScale
         size = self.attributes['size'] * printerScale
@@ -320,38 +305,60 @@ class PolyMarker(PolyPoints):
         fillstyle = self.attributes['fillstyle']
         marker = self.attributes['marker']
 
-        ###### May be removed ######
         if colour and not isinstance(colour, wx.Colour):
             colour = wx.NamedColour(colour)
         if fillcolour and not isinstance(fillcolour, wx.Colour):
             fillcolour = wx.NamedColour(fillcolour)
 
-        dc.SetPen(wx.Pen(colour, width))
+        gc.SetPen(wx.Pen(colour, width))
         if fillcolour:
-            dc.SetBrush(wx.Brush(fillcolour,fillstyle))
+            gc.SetBrush(wx.Brush(fillcolour,fillstyle))
         else:
-            dc.SetBrush(wx.Brush(colour, fillstyle))
+            gc.SetBrush(wx.Brush(colour, fillstyle))
         if coord == None:
-            self._drawmarkers(dc, self.scaled, marker, size)
+            self._drawmarkers(gc, self.scaled, marker, size)
         else:
-            self._drawmarkers(dc, coord, marker, size) # draw legend marker
+            self._drawmarkers(gc, coord, marker, size) # draw legend marker
 
     def getSymExtent(self, printerScale):
         """Width and Height of Marker"""
         s= 5*self.attributes['size'] * printerScale
         return (s,s)
 
-    def _drawmarkers(self, dc, coords, marker, size=1):
+    def _drawmarkers(self, gc, coords, marker, size=1):
         f = eval('self._' + marker)
-        f(dc, coords, size)
+        f(gc, coords, size)
 
-    def _bmp(self, dc, coords, size=1):
-        coords = coords - [3, 3]
-        [dc.DrawBitmapPoint(self.circleBitmap, pt, True) for pt in coords]
+    def _bmp(self, gc, coords, size=1):
+        path = gc.CreatePath()
+        path.AddCircle(0, 0, 3)
+        gc.PushState()
+        last = (0, 0)
+        for c in coords:
+            dx, dy = c[0] - last[0], c[1] - last[1]
+            gc.Translate(dx, dy)
+            gc.FillPath(path)
+            last = c
+        gc.PopState()
 
-    def _bmpsel(self, dc, coords, size=1):
-        coords = coords - [4, 4]
-        [dc.DrawBitmapPoint(self.circleBitmapSel, pt, True) for pt in coords]
+    def _bmpsel(self, gc, coords, size=1):
+        path = gc.CreatePath()
+        path.AddCircle(0, 0, 3.5)
+        gc.PushState()
+        last = (0, 0)
+        for c in coords:
+            dx, dy = c[0] - last[0], c[1] - last[1]
+            gc.Translate(dx, dy)
+            gc.DrawPath(path)
+            last = c
+        gc.PopState()
+
+    def _none(self, gc, coords, size=1):
+        pass
+
+    ### Not used within Cecilia 5 ###
+    def _dot(self, dc, coords, size=1):
+        dc.DrawPointList(coords)
 
     def _circle(self, dc, coords, size=1):
         fact= 2.5*size
@@ -360,9 +367,6 @@ class PolyMarker(PolyPoints):
         rect[:,0:2]= coords-[fact,fact]
         dc.DrawEllipseList(rect.astype(_Numeric.Int32))
 
-    def _dot(self, dc, coords, size=1):
-        dc.DrawPointList(coords)
-
     def _square(self, dc, coords, size=1):
         fact= 2.5*size
         wh= 5.0*size
@@ -383,7 +387,7 @@ class PolyMarker(PolyPoints):
         poly.shape= (len(coords),3,2)
         poly += shape
         dc.DrawPolygonList(poly.astype(_Numeric.Int32))
-      
+
     def _cross(self, dc, coords, size=1):
         fact= 2.5*size
         for f in [[-fact,-fact,fact,fact],[-fact,fact,fact,-fact]]:
@@ -395,6 +399,7 @@ class PolyMarker(PolyPoints):
         for f in [[-fact,0,fact,0],[0,-fact,0,fact]]:
             lines= _Numeric.concatenate((coords,coords),axis=1)+f
             dc.DrawLineList(lines.astype(_Numeric.Int32))
+    #################################
 
 class PlotGraphics:
     """Container to hold PolyXXX objects and graph labels
@@ -422,7 +427,7 @@ class PlotGraphics:
             return
         for o in self.objects:
             o.setLogScale(logscale)
-        
+
     def boundingBox(self):
         p1, p2 = self.objects[0].boundingBox()
         for o in self.objects[1:]:
@@ -446,7 +451,7 @@ class PlotGraphics:
     def setYLabel(self, yLabel= ''):
         """Set the Y axis label on the graph"""
         self.yLabel= yLabel
-        
+
     def setTitle(self, title= ''):
         """Set the title at the top of graph"""
         self.title= title
@@ -463,10 +468,10 @@ class PlotGraphics:
         """Get the title at the top of graph"""
         return self.title
 
-    def draw(self, dc):
+    def draw(self, gc):
         for o in self.objects:
             #t=_time.clock()          # profile info
-            o.draw(dc, self.printerScale)
+            o.draw(gc, self.printerScale)
             #dt= _time.clock()-t
             #print o, "time=", dt
 
@@ -477,14 +482,14 @@ class PlotGraphics:
             oSymExt = o.getSymExtent(printerScale)
             symExt = _Numeric.maximum(symExt, oSymExt)
         return symExt
-    
+
     def getLegendNames(self):
         """Returns list of legend names"""
         lst = [None]*len(self)
         for i in range(len(self)):
             lst[i]= self.objects[i].getLegend()
         return lst
-            
+
     def __len__(self):
         return len(self.objects)
 
@@ -520,13 +525,13 @@ class PlotCanvas(wx.Panel):
                  size=wx.DefaultSize, style=0, name="plotCanvas"):
         """Constructs a panel, which can be a child of a frame or
         any other non-control window"""
-    
+
         wx.Panel.__init__(self, parent, id, pos, size, style, name)
 
         sizer = wx.FlexGridSizer(2,2,0,0)
         self.canvas = wx.Window(self, -1)
         self.canvas.SetToolTip(CECTooltip(TT_GRAPHER))
-        
+
         self.sb_vert = wx.ScrollBar(self, -1, style=wx.SB_VERTICAL)
         self.sb_vert.SetScrollbar(0,1000,1000,1000)
         self.sb_hor = wx.ScrollBar(self, -1, style=wx.SB_HORIZONTAL)
@@ -536,20 +541,20 @@ class PlotCanvas(wx.Panel):
         sizer.Add(self.sb_vert, 0, wx.EXPAND)
         sizer.Add(self.sb_hor, 0, wx.EXPAND)
         sizer.Add((0,0))
-        
+
         sizer.AddGrowableRow(0, 1)
         sizer.AddGrowableCol(0, 1)
 
         self.sb_vert.Show(False)
         self.sb_hor.Show(False)
-        
+
         self.SetSizer(sizer)
         self.Fit()
 
         self.border = (1,1)
 
         self.SetBackgroundColour("white")
-        
+
         # Create some mouse events for zooming
         self.canvas.Bind(wx.EVT_LEFT_DOWN, self.OnMouseLeftDown)
         self.canvas.Bind(wx.EVT_LEFT_UP, self.OnMouseLeftUp)
@@ -571,7 +576,7 @@ class PlotCanvas(wx.Panel):
         self.HandCursor = wx.StockCursor(wx.CURSOR_HAND)
         self.GrabHandCursor = wx.StockCursor(wx.CURSOR_HAND)
         self.MagCursor = wx.StockCursor(wx.CURSOR_MAGNIFIER)
-            
+
         # Things for printing
         self.print_data = wx.PrintData()
         self.print_data.SetPaperId(wx.PAPER_LETTER)
@@ -590,10 +595,10 @@ class PlotCanvas(wx.Panel):
         self._sb_yfullrange = 0
         self._sb_xunit = 0
         self._sb_yunit = 0
-        
+
         self._dragEnabled = False
         self._screenCoordinates = _Numeric.array([0.0, 0.0])
-        
+
         self._logscale = (False, False)
         self._background_bitmap = None
         self._oldSize = wx.Size(0,0)
@@ -605,7 +610,7 @@ class PlotCanvas(wx.Panel):
         self._zoomCorner2= _Numeric.array([0.0, 0.0])   # left mouse up corner
         self._zoomEnabled= False
         self._hasDragged= False
-        
+
         # Drawing Variables
         self.last_draw = None
         self._pointScale= 1
@@ -615,18 +620,19 @@ class PlotCanvas(wx.Panel):
         self._gridEnabled= False
         self._legendEnabled= False
         self._titleEnabled= True
-        
+        self._clientSize = (0, 0)
+
         # Fonts
         self._fontCache = {}
         self._fontSizeAxis= 9
         self._fontSizeTitle= 15
         self._fontSizeLegend= 10
 
-        # Values to print on graph 
+        # Values to print on graph
         self._posToDrawValues = (0,0)
         self._Xvalue = ''
         self._Yvalue = ''
-        
+
         # corners from selection rect
         self._selectionCorner1 = None
         self._selectionCorner2 = None
@@ -663,10 +669,10 @@ class PlotCanvas(wx.Panel):
     def drawSelectionRect(self, c1, c2):
         self._selectionCorner1 = c1
         self._selectionCorner2 = c2
-            
+
     def SetCursor(self, cursor):
         self.canvas.SetCursor(cursor)
-        
+
     def GetGridColour(self):
         return self._gridColour
 
@@ -684,13 +690,13 @@ class PlotCanvas(wx.Panel):
 
     def setBackgroundBitmap(self, bit):
         self._background_bitmap = bit
-        
+
     # SaveFile
     def SaveFile(self, fileName= ''):
         """Saves the file to the type specified in the extension. If no file
         name is specified a dialog box is provided.  Returns True if sucessful,
         otherwise False.
-        
+
         .bmp  Save a Windows bitmap file.
         .xbm  Save an X bitmap file.
         .xpm  Save an XPM bitmap file.
@@ -699,7 +705,7 @@ class PlotCanvas(wx.Panel):
         """
         if _string.lower(fileName[-3:]) not in ['bmp','xbm','xpm','png','jpg']:
             dlg1 = wx.FileDialog(
-                    self, 
+                    self,
                     "Choose a file with extension bmp, gif, xbm, xpm, png, or jpg", ".", "",
                     "BMP files (*.bmp)|*.bmp|XBM files (*.xbm)|*.xbm|XPM file (*.xpm)|*.xpm|PNG files (*.png)|*.png|JPG files (*.jpg)|*.jpg",
                     wx.SAVE|wx.OVERWRITE_PROMPT
@@ -756,7 +762,7 @@ class PlotCanvas(wx.Panel):
                 self.print_data=wx.PrintData(data.GetPrintData()) # updates print_data
         finally:
             dlg.Destroy()
-                
+
     def Printout(self, paper=None):
         """Print current plot."""
         if paper != None:
@@ -803,15 +809,15 @@ class PlotCanvas(wx.Panel):
 
     def getLogScale(self):
         return self._logscale
-    
+
     def SetFontSizeAxis(self, point= 10):
         """Set the tick and axis label font size (default is 10 point)"""
         self._fontSizeAxis= point
-        
+
     def GetFontSizeAxis(self):
         """Get current tick and axis label font size in points"""
         return self._fontSizeAxis
-    
+
     def SetFontSizeTitle(self, point= 15):
         """Set Title font size (default is 15 point)"""
         self._fontSizeTitle= point
@@ -819,11 +825,11 @@ class PlotCanvas(wx.Panel):
     def GetFontSizeTitle(self):
         """Get current Title font size in points"""
         return self._fontSizeTitle
-    
+
     def SetFontSizeLegend(self, point= 7):
         """Set Legend font size (default is 7 point)"""
         self._fontSizeLegend= point
-        
+
     def GetFontSizeLegend(self):
         """Get current Legend font size in points"""
         return self._fontSizeLegend
@@ -853,7 +859,7 @@ class PlotCanvas(wx.Panel):
             self.SetCursor(self.ArrowCursor)
         elif tool == 1:
             self.SetCursor(self.PencilCursor)
-        
+
     def SetEnableDrag(self, value, tool=0):
         """Set True to enable drag."""
         if value not in [True,False]:
@@ -866,10 +872,10 @@ class PlotCanvas(wx.Panel):
             if tool == 0:
                 self.SetCursor(self.ArrowCursor)
         self._dragEnabled = value
-    
+
     def GetEnableDrag(self):
         return self._dragEnabled
-    
+
     def SetEnableZoom(self, value, tool=0):
         """Set True to enable zooming."""
         if value not in [True,False]:
@@ -902,7 +908,7 @@ class PlotCanvas(wx.Panel):
         """Set True to enable legend."""
         if value not in [True,False]:
             raise TypeError, "Value should be True or False"
-        self._legendEnabled= value 
+        self._legendEnabled= value
         self.Redraw()
 
     def GetEnableLegend(self):
@@ -913,7 +919,7 @@ class PlotCanvas(wx.Panel):
         """Set True to enable title."""
         if value not in [True,False]:
             raise TypeError, "Value should be True or False"
-        self._titleEnabled= value 
+        self._titleEnabled= value
         self.Redraw()
 
     def GetEnableTitle(self):
@@ -924,7 +930,7 @@ class PlotCanvas(wx.Panel):
         """Set True to enable pointLabel."""
         if value not in [True,False]:
             raise TypeError, "Value should be True or False"
-        self._pointLabelEnabled= value 
+        self._pointLabelEnabled= value
         self.Redraw()  #will erase existing pointLabel if present
         self.last_PointLabel = None
 
@@ -947,8 +953,8 @@ class PlotCanvas(wx.Panel):
         self.last_PointLabel = None        #reset pointLabel
         if self.last_draw is not None:
             self._Draw(self.last_draw[0])
-        
-    def ScrollRight(self, units):          
+
+    def ScrollRight(self, units):
         """Move view right number of axis units."""
         self.last_PointLabel = None        #reset pointLabel
         if self.last_draw is not None:
@@ -972,7 +978,7 @@ class PlotCanvas(wx.Panel):
         if self.getLogScale()[1]:
             y = _Numeric.power(10,y)
         return x,y
-        
+
     def _getXY(self,event):
         """Takes a mouse event and returns the XY user axis values."""
         x,y= self.PositionScreenToUser(event.GetPosition())
@@ -983,13 +989,13 @@ class PlotCanvas(wx.Panel):
         userPos= _Numeric.array(pntXY)
         x,y= userPos * self._pointScale + self._pointShift
         return x,y
-        
+
     def PositionScreenToUser(self, pntXY):
         """Converts Screen position to User Coordinates"""
         screenPos= _Numeric.array(pntXY)
         x,y= (screenPos-self._pointShift)/self._pointScale
         return x,y
-        
+
     def SetXSpec(self, type= 'auto'):
         """xSpec- defines x axis type. Can be 'none', 'min' or 'auto'
         where:
@@ -998,7 +1004,7 @@ class PlotCanvas(wx.Panel):
             'auto' - rounds axis range to sensible values
         """
         self._xSpec= type
-        
+
     def SetYSpec(self, type= 'auto'):
         """ySpec- defines x axis type. Can be 'none', 'min' or 'auto'
         where:
@@ -1011,11 +1017,11 @@ class PlotCanvas(wx.Panel):
     def GetXSpec(self):
         """Returns current XSpec for axis"""
         return self._xSpec
-    
+
     def GetYSpec(self):
         """Returns current YSpec for axis"""
         return self._ySpec
-    
+
     def GetXMaxRange(self):
         xAxis = self._getXMaxRange()
         if self.getLogScale()[0]:
@@ -1051,7 +1057,7 @@ class PlotCanvas(wx.Panel):
     def _getXCurrentRange(self):
         """Returns (minX, maxX) x-axis for currently displayed portion of graph"""
         return self.last_draw[1]
-    
+
     def GetYCurrentRange(self):
         yAxis = self._getYCurrentRange()
         if self.getLogScale()[1]:
@@ -1064,15 +1070,15 @@ class PlotCanvas(wx.Panel):
 
     def Draw(self, graphics, xAxis = None, yAxis = None, dc = None):
         """Wrapper around _Draw, which handles log axes"""
-        
+
         graphics.setLogScale(self.getLogScale())
-        
+
         # check Axis is either tuple or none
         if type(xAxis) not in [type(None),tuple]:
             raise TypeError, "xAxis should be None or (minX,maxX)"+str(type(xAxis))
         if type(yAxis) not in [type(None),tuple]:
             raise TypeError, "yAxis should be None or (minY,maxY)"+str(type(xAxis))
-             
+
         # check case for axis = (a,b) where a==b caused by improper zooms
         if xAxis != None:
             if xAxis[0] == xAxis[1]:
@@ -1085,14 +1091,14 @@ class PlotCanvas(wx.Panel):
             if self.getLogScale()[1]:
                 yAxis = _Numeric.log10(yAxis)
         self._Draw(graphics, xAxis, yAxis, dc)
-        
+
     def _Draw(self, graphics, xAxis = None, yAxis = None, dc = None):
         """\
         Draw objects in graphics with specified x and y axis.
         graphics- instance of PlotGraphics with list of PolyXXX objects
         xAxis - tuple with (min, max) axis range to view
         yAxis - same as xAxis
-        dc - drawing context - doesn't have to be specified.    
+        dc - drawing context - doesn't have to be specified.
         If it's not, the offscreen buffer is used
         """
         if self._zoomed:
@@ -1119,13 +1125,13 @@ class PlotCanvas(wx.Panel):
         self.last_draw = (graphics, _Numeric.array(xAxis), _Numeric.array(yAxis))       # saves most recient values
 
         if dc == None:
-            # sets new dc and clears it 
+            # sets new dc and clears it
             dc = wx.BufferedDC(wx.ClientDC(self.canvas), self._Buffer)
             dc.Clear()
-            
+            gc = wx.GraphicsContext_Create(dc)
+
         dc.BeginDrawing()
-        # dc.Clear()
-        
+
         # set font size for every thing but title and legend
         dc.SetFont(self._getFont(self._fontSizeAxis))
 
@@ -1194,7 +1200,7 @@ class PlotCanvas(wx.Panel):
         shift = -p1 * scale + self.plotbox_origin + textSize_shift * _Numeric.array((1,-1))
         self._pointScale = scale  # make available for mouse events
         self._pointShift = shift
-        
+
         size = dc.GetSize()
         dc.SetPen(wx.Pen(self._backColour, 1))
         dc.SetBrush(wx.Brush(self._backColour))
@@ -1207,16 +1213,16 @@ class PlotCanvas(wx.Panel):
             dc.DrawBitmap(self._scaled_background_bitmap, ptx, pty)
 
         self._drawAxes(dc, p1, p2, scale, shift, xticks, yticks)
-        
+
         graphics.scaleAndShift(scale, shift)
         graphics.setPrinterScale(self.printerScale)  # thicken up lines and markers if printing
-        
+
         # set clipping area so drawing does not occur outside axis box
         ptx,pty,rectWidth,rectHeight= self._point2ClientCoord(p1, p2)
         dc.SetClippingRegion(ptx-5,pty-5,rectWidth+10,rectHeight+10)
 
         # Draw the lines and markers
-        graphics.draw(dc)
+        graphics.draw(gc)
 
         # Draw position values on graph ------------------------------
         pos1,pos2 = self._onePoint2ClientCoord(self._posToDrawValues)
@@ -1238,7 +1244,7 @@ class PlotCanvas(wx.Panel):
         dc.EndDrawing()
 
         self._adjustScrollbars()
-        
+
     def Redraw(self, dc=None):
         """Redraw the existing plot."""
         if self.last_draw is not None:
@@ -1290,13 +1296,13 @@ class PlotCanvas(wx.Panel):
         #[curveNumber, legend, index of closest point, pointXY, scaledXY, distance]
         cn = [curveNum]+ [obj.getLegend()]+ obj.getClosestPoint( pntXY, pointScaled)
         return cn
-        
+
     def GetClosestPoints(self, pntXY, pointScaled= True):
         """Returns list with
             [curveNumber, legend, index of closest point, pointXY, scaledXY, distance]
             list for each curve.
             Returns [] if no curves are being plotted.
-            
+
             x, y in user coords
             if pointScaled == True based on screen coords
             if pointScaled == False based on user coords
@@ -1320,7 +1326,7 @@ class PlotCanvas(wx.Panel):
             [curveNumber, legend, index of closest point, pointXY, scaledXY, distance]
             list for only the closest curve.
             Returns [] if no curves are being plotted.
-            
+
             x, y in user coords
             if pointScaled == True based on screen coords
             if pointScaled == False based on user coords
@@ -1335,7 +1341,7 @@ class PlotCanvas(wx.Panel):
         mdist = min(dists)  #Min dist
         i = dists.index(mdist)  #index for min dist
         return closestPts[i]  #this is the closest point on closest curve
-    
+
     GetClosetPoint = GetClosestPoint
 
     def UpdatePointLabel(self, mDataDict):
@@ -1348,7 +1354,7 @@ class PlotCanvas(wx.Panel):
             you specify.
 
             This function can be called from parent window with onClick,
-            onMotion events etc.            
+            onMotion events etc.
         """
         if self.last_PointLabel != None:
             #compare pointXY
@@ -1382,7 +1388,7 @@ class PlotCanvas(wx.Panel):
                 yAxis -= dist[1]
                 xAxis -= dist[0]
                 self._Draw(graphics,xAxis,yAxis)
-            
+
     def OnMouseLeftDown(self,event):
         self._zoomCorner1[0], self._zoomCorner1[1]= self._getXY(event)
         self._screenCoordinates = _Numeric.array(event.GetPosition())
@@ -1416,7 +1422,7 @@ class PlotCanvas(wx.Panel):
             # before (possibly) removing the scrollbars and trigering
             # size events, etc.
             wx.FutureCall(200,self.Reset)
-        
+
     def OnMouseRightDown(self,event):
         if self._zoomEnabled:
             X,Y = self._getXY(event)
@@ -1433,14 +1439,14 @@ class PlotCanvas(wx.Panel):
     def OnSize(self,event):
         # The Buffer init is done here, to make sure the buffer is always
         # the same size as the Window
-        Size  = self.canvas.GetClientSize()
-        Size.width = max(1, Size.width)
-        Size.height = max(1, Size.height)
-        
+        size  = self.canvas.GetClientSize()
+        size.width = max(1, size.width)
+        size.height = max(1, size.height)
+
         # Make new offscreen bitmap: this bitmap will always have the
         # current drawing in it, so it can be used to save the image to
         # a file, or whatever.
-        self._Buffer = wx.EmptyBitmap(Size.width, Size.height)
+        self._Buffer = wx.EmptyBitmap(size.width, size.height)
         self._setSize()
 
         self.last_PointLabel = None        #reset pointLabel
@@ -1448,8 +1454,10 @@ class PlotCanvas(wx.Panel):
         if self.last_draw is None:
             self.Clear()
         else:
-            graphics, xSpec, ySpec = self.last_draw
-            self._Draw(graphics,xSpec,ySpec)
+            if self._clientSize != size:
+                self._clientSize = size
+                graphics, xSpec, ySpec = self.last_draw
+                self._Draw(graphics,xSpec,ySpec)
 
     def OnLeave(self, event):
         """Used to erase pointLabel when mouse outside window"""
@@ -1461,21 +1469,24 @@ class PlotCanvas(wx.Panel):
         if not self._adjustingSB:
             self._sb_ignore = True
             sbpos = evt.GetPosition()
-        
+
             if evt.GetOrientation() == wx.VERTICAL:
                 fullrange,pagesize = self.sb_vert.GetRange(),self.sb_vert.GetPageSize()
                 sbpos = fullrange-pagesize-sbpos
                 dist = sbpos*self._sb_yunit-(self._getYCurrentRange()[0]-self._sb_yfullrange[0])
                 self.ScrollUp(dist)
-            
+
             if evt.GetOrientation() == wx.HORIZONTAL:
                 dist = sbpos*self._sb_xunit-(self._getXCurrentRange()[0]-self._sb_xfullrange[0])
                 self.ScrollRight(dist)
-               
+
     # Private Methods **************************************************
     def drawCursor(self, time):
         pt = time * self._pointScale + self._pointShift
-        self.time = pt[0]
+        try:
+            self.time = pt[0]
+        except:
+            pass
         self.GetParent().cursorPanel.setTime(self.time)
 
     def _setSize(self, width=None, height=None):
@@ -1483,17 +1494,17 @@ class PlotCanvas(wx.Panel):
         if width == None:
             (self.width,self.height) = self.canvas.GetClientSize()
         else:
-            self.width, self.height= width,height    
+            self.width, self.height= width,height
         self.plotbox_size = 0.97*_Numeric.array([self.width, self.height])
         xo = 0.5*(self.width-self.plotbox_size[0])
         yo = self.height-0.5*(self.height-self.plotbox_size[1])
         self.plotbox_origin = _Numeric.array([xo, yo])
-    
+
     def _setPrinterScale(self, scale):
         """Used to thicken lines and increase marker size for print out."""
         # line thickness on printer is very thin at 600 dot/in. Markers small
         self.printerScale= scale
-     
+
     def _printDraw(self, printDC):
         """Used for printing."""
         if self.last_draw != None:
@@ -1560,7 +1571,7 @@ class PlotCanvas(wx.Panel):
         xLabelWH= dc.GetTextExtent(xLabel)
         yLabelWH= dc.GetTextExtent(yLabel)
         return titleWH, xLabelWH, yLabelWH
-    
+
     def _legendWH(self, dc, graphics):
         """Returns the size in screen units for legend box"""
         if self._legendEnabled != True:
@@ -1574,7 +1585,7 @@ class PlotCanvas(wx.Panel):
             txtExt= dc.GetTextExtent(txtList[0])
             for txt in graphics.getLegendNames()[1:]:
                 txtExt= _Numeric.maximum(txtExt,dc.GetTextExtent(txt))
-            maxW= symExt[0]+txtExt[0]    
+            maxW= symExt[0]+txtExt[0]
             maxH= max(symExt[1],txtExt[1])
             # padding .1 for lhs of legend box and space between lines
             maxW= maxW* 1.1
@@ -1599,7 +1610,7 @@ class PlotCanvas(wx.Panel):
     def _getFont(self,size):
         """Take font size, adjusts if printing and returns wx.Font"""
         s = size*self.printerScale
-        font = wx.Font(s, wx.NORMAL, wx.NORMAL, wx.NORMAL, face=FONT_FACE)
+        font = wx.Font(s, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, face=FONT_FACE)
         #of = self.GetFont()
         # Linux speed up to get font from cache rather than X font server
         #key = (int(s), of.GetFamily (), of.GetStyle (), of.GetWeight ())
@@ -1618,7 +1629,7 @@ class PlotCanvas(wx.Panel):
         pt1= c1*self._pointScale+self._pointShift
         ptx,pty= pt1
         return ptx, pty
-    
+
     def _point2ClientCoord(self, corner1, corner2):
         """Converts user point coords to client screen int coords x,y,width,height"""
         c1= _Numeric.array(corner1)
@@ -1631,8 +1642,8 @@ class PlotCanvas(wx.Panel):
         plr= _Numeric.maximum(pt1,pt2) # Lower right corner
         rectWidth, rectHeight= plr-pul
         ptx,pty= pul
-        return ptx, pty, rectWidth, rectHeight 
-    
+        return ptx, pty, rectWidth, rectHeight
+
     def _axisInterval(self, spec, lower, upper):
         """Returns sensible axis range for given spec"""
         if spec == 'none' or spec == 'min':
@@ -1665,10 +1676,10 @@ class PlotCanvas(wx.Panel):
             raise ValueError, str(spec) + ': illegal axis specification'
 
     def _drawAxes(self, dc, p1, p2, scale, shift, xticks, yticks):
-        
+
         penWidth= self.printerScale        # increases thickness for printing only
         dc.SetPen(wx.Pen(self._gridColour, penWidth))
-        
+
         # set length of tick marks--long ones make grid
         if self._gridEnabled:
             x,y,width,height= self._point2ClientCoord(p1,p2)
@@ -1739,13 +1750,13 @@ class PlotCanvas(wx.Panel):
             return self._logticks(*args)
         else:
             return self._ticks(*args)
-    
+
     def _yticks(self, *args):
         if self._logscale[1]:
             return self._logticks(*args)
         else:
             return self._ticks(*args)
-        
+
     def _logticks(self, lower, upper):
         #lower,upper = map(_Numeric.log10,[lower,upper])
         #print 'logticks',lower,upper
@@ -1782,7 +1793,7 @@ class PlotCanvas(wx.Panel):
         if len(ticks) == 0:
             ticks = [(0,'')]
         return ticks
-    
+
     def _ticks(self, lower, upper):
         ideal = (upper-lower)/7.
         log = _Numeric.log10(ideal)
@@ -1797,7 +1808,7 @@ class PlotCanvas(wx.Panel):
                 factor = f
         grid = factor * 10.**power
         if self._useScientificNotation and (power > 4 or power < -4):
-            format = '%+7.1e'        
+            format = '%+7.1e'
         elif power >= 0:
             digits = max(1, int(power))
             format = '%' + `digits`+'.0f'
@@ -1823,7 +1834,7 @@ class PlotCanvas(wx.Panel):
 
         self._adjustingSB = True
         needScrollbars = False
-        
+
         # horizontal scrollbar
         r_current = self._getXCurrentRange()
         r_max = list(self._getXMaxRange())
@@ -1831,12 +1842,12 @@ class PlotCanvas(wx.Panel):
 
         r_max[0] = min(r_max[0],r_current[0])
         r_max[1] = max(r_max[1],r_current[1])
-            
+
         self._sb_xfullrange = r_max
 
         unit = (r_max[1]-r_max[0])/float(self.sb_hor.GetRange())
         pos = int((r_current[0]-r_max[0])/unit)
-        
+
         if pos >= 0:
             pagesize = int((r_current[1]-r_current[0])/unit)
 
@@ -1853,12 +1864,12 @@ class PlotCanvas(wx.Panel):
 
         r_max[0] = min(r_max[0],r_current[0])
         r_max[1] = max(r_max[1],r_current[1])
-            
+
         self._sb_yfullrange = r_max
-        
+
         unit = (r_max[1]-r_max[0])/sbfullrange
         pos = int((r_current[0]-r_max[0])/unit)
-        
+
         if pos >= 0:
             pagesize = int((r_current[1]-r_current[0])/unit)
             pos = (sbfullrange-1-pos-pagesize)
@@ -1871,6 +1882,7 @@ class PlotCanvas(wx.Panel):
         self.SetShowScrollbars(needScrollbars)
         self._adjustingSB = False
 
+# CHECK: Remove all about printer...
 #-------------------------------------------------------------------------------
 # Used to layout the printer page
 
@@ -1905,14 +1917,14 @@ class PlotPrintout(wx.Printout):
         dcSize= dc.GetSize()                    # DC size
         pageSize= self.GetPageSizePixels() # page size in terms of pixcels
         clientDcSize= self.graph.GetClientSize()
-        
+
         # find what the margins are (mm)
         margLeftSize,margTopSize= self.graph.pageSetupData.GetMarginTopLeft()
         margRightSize, margBottomSize= self.graph.pageSetupData.GetMarginBottomRight()
 
         # calculate offset and scale for dc
         pixLeft= margLeftSize*PPIPrinter[0]/25.4  # mm*(dots/in)/(mm/in)
-        pixRight= margRightSize*PPIPrinter[0]/25.4    
+        pixRight= margRightSize*PPIPrinter[0]/25.4
         pixTop= margTopSize*PPIPrinter[1]/25.4
         pixBottom= margBottomSize*PPIPrinter[1]/25.4
 
@@ -1927,10 +1939,10 @@ class PlotPrintout(wx.Printout):
             pixTop *= ratioH
             plotAreaW *= ratioW
             plotAreaH *= ratioH
-        
+
         # rescale plot to page or preview plot area
         self.graph._setSize(plotAreaW,plotAreaH)
-        
+
         # Set offset and scale
         dc.SetDeviceOrigin(pixLeft,pixTop)
 
@@ -1948,4 +1960,3 @@ class PlotPrintout(wx.Printout):
 
         return True
 
-
