@@ -18,7 +18,7 @@ You should have received a copy of the GNU General Public License
 along with Cecilia 5.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-import wx, time, random, bisect
+import wx, random, bisect
 from wx.lib.stattext import GenStaticText
 import CeciliaPlot as plot
 import math, copy
@@ -44,82 +44,7 @@ except:
             (it's not part of the standard Python distribution). See the
             Numeric Python site (http://numpy.scipy.org) for information on
             downloading source or binaries."""
-            raise ImportError, "Numeric,numarray or NumPy not found. \n" + msg
-
-def chooseColour(i, numlines):
-    def clip(x):
-        val = int(x*255)
-        if val < 0: val = 0
-        elif val > 255: val = 255
-        else: val = val
-        return val
-
-    def colour(i, numlines, sat, bright):
-        hue = (i / float(numlines)) * 315
-        segment = math.floor(hue / 60) % 6
-        fraction = hue / 60 - segment
-        t1 = bright * (1 - sat)
-        t2 = bright * (1 - (sat * fraction))
-        t3 = bright * (1 - (sat * (1 - fraction)))
-        if segment == 0:
-            r, g, b = bright, t3, t1
-        elif segment == 1:
-            r, g, b = t2, bright, t1
-        elif segment == 2:
-            r, g, b = t1, bright, t3
-        elif segment == 3:
-            r, g, b = t1, t2, bright
-        elif segment == 4:
-            r, g, b = t3, t1, bright
-        elif segment == 5:
-            r, g, b = bright, t1, t2
-        return wx.Colour(clip(r),clip(g),clip(b))
-
-    lineColour = colour(i, numlines, 1, 1)
-    midColour = colour(i, numlines, .5, .5)
-    knobColour = colour(i, numlines, .8, .5)
-    sliderColour = colour(i, numlines, .5, .75)
-
-    return [lineColour, midColour, knobColour, sliderColour]
-
-def chooseColourFromName(name):
-    def clip(x):
-        val = int(x*255)
-        if val < 0: val = 0
-        elif val > 255: val = 255
-        else: val = val
-        return val
-
-    def colour(name):
-        vals = COLOUR_CLASSES[name]
-        hue = vals[0]
-        bright = vals[1]
-        sat = vals[2]
-        segment = int(math.floor(hue / 60))
-        fraction = hue / 60 - segment
-        t1 = bright * (1 - sat)
-        t2 = bright * (1 - (sat * fraction))
-        t3 = bright * (1 - (sat * (1 - fraction)))
-        if segment == 0:
-            r, g, b = bright, t3, t1
-        elif segment == 1:
-            r, g, b = t2, bright, t1
-        elif segment == 2:
-            r, g, b = t1, bright, t3
-        elif segment == 3:
-            r, g, b = t1, t2, bright
-        elif segment == 4:
-            r, g, b = t3, t1, bright
-        elif segment == 5:
-            r, g, b = bright, t1, t2
-        return wx.Colour(clip(r),clip(g),clip(b))
-
-    lineColour = colour(name)
-    midColour = colour(name)
-    knobColour = colour(name)
-    sliderColour = colour(name)
-
-    return [lineColour, midColour, knobColour, sliderColour]
+            raise ImportError, "Numeric, numarray or NumPy not found. \n" + msg
 
 class MyFileDropTarget(wx.FileDropTarget):
     def __init__(self, window):
@@ -147,7 +72,7 @@ class Line:
         self.suffix = suffix
         self.colour = colour[0]
         self.midColour = colour[1]
-        self.knobColour = colour[2]  
+        self.knobColour = colour[2]
         self.sliderColour = colour[3]
         # curved variables
         self.curved = curved
@@ -156,9 +81,12 @@ class Line:
         self.initData = self.getLineState()
         self.modified = True
 
+    def reinit(self):
+        self.setLineState(self.initData)
+
     def getModified(self):
         return self.modified
-        
+
     def setModified(self, state):
         self.modified = state
 
@@ -185,16 +113,16 @@ class Line:
 
     def getColour(self):
         return self.colour
-    
+
     def getMidColour(self):
         return self.midColour
 
     def getSuffix(self):
         return self.suffix
-        
+
     def getData(self):
         return self.data
-        
+
     def setData(self, list):
         self.data = list
         self.checkIfCurved()
@@ -324,7 +252,7 @@ class Line:
         if self.getCurved():
             self.curved = False
             self.setCurvedLine()
-     
+
 class Grapher(plot.PlotCanvas):
     def __init__(self, parent, style=wx.EXPAND):
         plot.PlotCanvas.__init__(self, parent, style=wx.EXPAND | wx.WANTS_CHARS)
@@ -367,6 +295,10 @@ class Grapher(plot.PlotCanvas):
         self.Bind(wx.EVT_CHAR, self.OnKeyDown)
         self.canvas.Bind(wx.EVT_CHAR, self.OnKeyDown)
         self.canvas.Bind(wx.EVT_LEAVE_WINDOW, self.OnLooseFocus)
+        self.canvas.Bind(wx.EVT_ENTER_WINDOW, self.OnGrabFocus)
+
+    def unselectPoints(self):
+        self.selectedPoints = []
 
     def OnLooseFocus(self, event):
         win = wx.FindWindowAtPointer()
@@ -375,7 +307,10 @@ class Grapher(plot.PlotCanvas):
             if win not in [CeciliaLib.getVar("mainFrame"), CeciliaLib.getVar("interface"), CeciliaLib.getVar("spectrumFrame")]:
                 win.Raise()
         event.Skip()
-        
+
+    def OnGrabFocus(self, event):
+        self.SetFocus()
+
     def setTool(self, tool):
         self._tool = tool
         if self._tool < 2:
@@ -412,13 +347,13 @@ class Grapher(plot.PlotCanvas):
     def resetSelectedPoints(self):
         self.selectedPoints = []
         self.draw()
-        
+
     def getSelected(self):
         return self.selected
 
     def sendSelected(self):
         self.parent.setSelected(self.selected)
-        
+
     def getLine(self, which):
         return self.data[which]
 
@@ -437,11 +372,11 @@ class Grapher(plot.PlotCanvas):
                     break
         self.draw()
 
-    def createLine(self, data, yrange, colour, label='', log=False, name='', size=8192, slider=None, suffix='', curved=False): 
+    def createLine(self, data, yrange, colour, label='', log=False, name='', size=8192, slider=None, suffix='', curved=False):
         if data[0][0] != 0: data[0][0] = 0
         if data[-1][0] != self.totaltime: data[-1][0] = self.totaltime
         self.data.append(Line(data, yrange, colour, label, log, name, size, slider, suffix, curved))
-        self.draw()
+        # self.draw()
 
     def onCopy(self):
         line = self.getLine(self.getSelected())
@@ -475,6 +410,11 @@ class Grapher(plot.PlotCanvas):
             if line.getSlider() != None:
                 line.getSlider().setPlay(1)
 
+    def onSelectAll(self):
+        data = self.getLine(self.getSelected()).getData()
+        self.selectedPoints = [i for i in range(len(data))]
+        self.draw()
+
     def checkForHistory(self, fromUndo=False):
         if self._oldData != self._currentData:
             self.addHistory(fromUndo)
@@ -505,7 +445,7 @@ class Grapher(plot.PlotCanvas):
             for i, l in enumerate(self.data):
                 l.setLineState(self._history[self._historyPoint][i])
             self.draw()
- 
+
         if len(self._history) > 0 :
             if self._historyPoint >= (len(self._history) - 1):
                 self.menubarUndo.Enable(False)
@@ -519,14 +459,6 @@ class Grapher(plot.PlotCanvas):
             self.menubarUndo.Enable(False)
             self.menubarRedo.Enable(False)
 
-    # zoom() is no more used... #
-    def zoom(self):
-        if self._zoomed:
-            minX, minY= _Numeric.minimum( self._zoomCorner1, self._zoomCorner2)
-            maxX, maxY= _Numeric.maximum( self._zoomCorner1, self._zoomCorner2)
-            if self.last_draw != None:
-                self._Draw(self.last_draw[0], xAxis = (minX,maxX), yAxis = (minY,maxY), dc = None)
-   
     def rescaleLinLin(self, data, yrange, currentYrange):
         scale = yrange[1] - yrange[0]
         currentScale = currentYrange[1] - currentYrange[0]
@@ -548,7 +480,7 @@ class Grapher(plot.PlotCanvas):
     def rescaleLinLog(self, data, yrange, currentYrange):
         list = []
         if yrange[0] == 0: yoffrange = .00001
-        else: yoffrange = yrange[0] 
+        else: yoffrange = yrange[0]
         totalRange = yrange[1] - yoffrange
         currentTotalRange = math.log10(currentYrange[1]/currentYrange[0])
         currentMin = math.log10(currentYrange[0])
@@ -601,6 +533,11 @@ class Grapher(plot.PlotCanvas):
         return data
 
     def draw(self):
+        wx.CallAfter(self._draw)
+
+    def _draw(self):
+        if len(self.data) == 0:
+            return
         lines = []
         markers = []
         self.visibleLines = []
@@ -622,7 +559,7 @@ class Grapher(plot.PlotCanvas):
             index = self.data.index(l)
             if index == self.lineOver:
                 col = 'black'
-            else: 
+            else:
                 col = l.getColour()
             if l.getShow():
                 if l.getCurved():
@@ -677,7 +614,7 @@ class Grapher(plot.PlotCanvas):
                     else:
                         dataToDraw = l.dataToDraw
                     line = plot.PolyLine(dataToDraw, colour=col, width=1, legend=l.getLabel())
-                    marker = plot.PolyMarker([], size=1, marker="dot")
+                    marker = plot.PolyMarker([], size=1, marker="none")
                 if l.getLog():
                     line.setLogScale((False, True))
                     marker.setLogScale((False, True))
@@ -688,9 +625,12 @@ class Grapher(plot.PlotCanvas):
                 lines.append(line)
                 markers.append(marker)
                 if self.selectedPoints and index == self.selected:
-                    selmarker = plot.PolyMarker([l.getData()[selp] for selp in self.selectedPoints], 
+                    try:
+                        selmarker = plot.PolyMarker([l.getData()[selp] for selp in self.selectedPoints],
                                                 size=1.5, marker="bmpsel", fillcolour='white')
-                    markers.append(selmarker)
+                        markers.append(selmarker)
+                    except:
+                        pass
                 self.visibleLines.append(l)
         lines.extend(markers)
 
@@ -864,7 +804,7 @@ class Grapher(plot.PlotCanvas):
                     maxX, maxY = _Numeric.maximum( self._zoomCorner1, self._zoomCorner2)
                     self._hasDragged = False  # reset flag
                     self.last_PointLabel = None        #reset pointLabel
-                    self._zoomed = True    
+                    self._zoomed = True
                     if self.last_draw != None:
                         self._Draw(self.last_draw[0], xAxis = (minX,maxX), yAxis = (minY,maxY), dc = None)
                 else:
@@ -893,14 +833,14 @@ class Grapher(plot.PlotCanvas):
             self.markSelectionStart = None
             self.drawSelectionRect(None, None)
             self.draw()
-            
+
         self.checkForHistory()
         self.movingCurve = False
         self.curve = None
         self.point = None
         self.setValuesToDraw(self._getXY(event))
         self.draw()
-    
+
     def OnMotion(self,event):
         if self._zoomEnabled and event.LeftIsDown() and self._tool > 1 and self.curve == None:
             if self._hasDragged:
@@ -946,7 +886,7 @@ class Grapher(plot.PlotCanvas):
                 self._zoomCorner2[0] = xAxis[1]
                 self._zoomCorner1[1] = yAxis[0]
                 self._zoomCorner2[1] = yAxis[1]
-                
+
                 self._Draw(graphics,xAxis,yAxis)
 
         if self._tool == 0:
@@ -962,8 +902,8 @@ class Grapher(plot.PlotCanvas):
                     if pos[0] < minboundary: X = minboundary
                     elif pos[0] > maxboundary: X = maxboundary
                     else: X = pos[0]
-                    
-                    if pos[1] < self.GetYCurrentRange()[0]: Y = self.GetYCurrentRange()[0] 
+
+                    if pos[1] < self.GetYCurrentRange()[0]: Y = self.GetYCurrentRange()[0]
                     elif pos[1] > self.GetYCurrentRange()[1]: Y = self.GetYCurrentRange()[1]
                     else: Y = pos[1]
 
@@ -1005,7 +945,7 @@ class Grapher(plot.PlotCanvas):
                             newypos =  self.templist[self.selectedPoints.index(p)][1] * offset[1]
                         else:
                             newypos =  self.templist[self.selectedPoints.index(p)][1] - offset[1]
-                        if newypos < self.GetYCurrentRange()[0]: Y = self.GetYCurrentRange()[0] 
+                        if newypos < self.GetYCurrentRange()[0]: Y = self.GetYCurrentRange()[0]
                         elif newypos > self.GetYCurrentRange()[1]: Y = self.GetYCurrentRange()[1]
                         else: Y = newypos
 
@@ -1037,8 +977,10 @@ class Grapher(plot.PlotCanvas):
                 self.draw()
 
             # Check for mouse over
-            else:
+            elif len(self.data) > 0:
                 self.lineOver = None
+                if self.selected >= len(self.data) or self.selected < 0:
+                    self.selected = 0
                 curve = self.data[self.selected]
 
                 # Check mouse over if curved
@@ -1139,13 +1081,16 @@ class Grapher(plot.PlotCanvas):
             self.parent.toolbar.radiotoolbox.setTool('hand')
         elif key in [wx.WXK_DELETE, wx.WXK_NUMPAD_DELETE, wx.WXK_BACK]:
             if self.selectedPoints:
-                points = [self.data[self.selected].getData()[p] for p in self.selectedPoints]
+                numpts = len(self.data[self.selected].getData())
+                points = [self.data[self.selected].getData()[p] for p in self.selectedPoints if p not in [0, numpts-1]]
                 for p in points:
-                    if not p[0] in [0.0, CeciliaLib.getVar("totalTime")]:
-                        self.data[self.selected].deletePointFromPoint(p)
+                    self.data[self.selected].deletePointFromPoint(p)
                 self.selectedPoints = []
                 self.draw()
                 self.checkForHistory()
+        elif key in [wx.WXK_LEFT, wx.WXK_RIGHT, wx.WXK_UP, wx.WXK_DOWN]:
+            # TODO: The idea here is to move the selected points with arrows
+            pass
 
         if self._zoomed and key == wx.WXK_ESCAPE:
             self._zoomed = False
@@ -1166,7 +1111,7 @@ class Grapher(plot.PlotCanvas):
     def clip(self, off, exXs, exYs):
         x,y = off
         minX, maxX = 0, self.getTotalTime()
-        minY, maxY = self.getLine(self.getSelected()).getYrange()[0], self.getLine(self.getSelected()).getYrange()[1] 
+        minY, maxY = self.getLine(self.getSelected()).getYrange()[0], self.getLine(self.getSelected()).getYrange()[1]
         if exXs[0] - x >= minX and exXs[1] - x <= maxX:
             x = x
         elif exXs[1] - x >= maxX:
@@ -1184,7 +1129,7 @@ class Grapher(plot.PlotCanvas):
     def clipLog(self, off, exXs, exYs):
         x,y = off
         minX, maxX = 0, self.getTotalTime()
-        minY, maxY = self.getLine(self.getSelected()).getYrange()[0], self.getLine(self.getSelected()).getYrange()[1] 
+        minY, maxY = self.getLine(self.getSelected()).getYrange()[0], self.getLine(self.getSelected()).getYrange()[1]
         if exXs[0] - x >= minX and exXs[1] - x <= maxX:
             x = x
         elif exXs[1] - x >= maxX:
@@ -1204,7 +1149,7 @@ class Grapher(plot.PlotCanvas):
         xscl = 1./self.totaltime
         yscl = 1./yscale
         return math.sqrt(pow((p2[0]-p1[0])*xscl, 2) + pow((p2[1]-p1[1])*yscl, 2))
-    
+
     def distanceLog(self, p1, p2, yrange):
         "Length of line between two points (based on X scale and Y ratio)"
         xscl = 1./self.totaltime
@@ -1212,10 +1157,10 @@ class Grapher(plot.PlotCanvas):
         return math.sqrt(pow((p2[0]-p1[0])*xscl, 2) + pow(Y, 2))
 
 class ToolBar(wx.Panel):
-    def __init__(self, parent, size=(-1,25), tools=[], toolFunctions=None):
+    def __init__(self, parent, size=(-1,30), tools=[], toolFunctions=None):
         wx.Panel.__init__(self, parent, -1, size=size)
         self.SetBackgroundColour(TITLE_BACK_COLOUR)
-        self.box = wx.FlexGridSizer(1, 7, 5, 0)
+        self.box = wx.FlexGridSizer(1, 7, 5, 5)
         self.parent = parent
         ffakePanel = wx.Panel(self, -1, size=(5, self.GetSize()[1]))
         ffakePanel.SetBackgroundColour(TITLE_BACK_COLOUR)
@@ -1228,12 +1173,14 @@ class ToolBar(wx.Panel):
         self.convertSlider.setBackColour(TITLE_BACK_COLOUR)
         self.convertSlider.SetToolTip(CECTooltip(TT_RES_SLIDER))
 
-        fakePanel = wx.Panel(self, -1, size=(10, self.GetSize()[1]))
+        tw, th = self.GetTextExtent("loading buffers...    ")
+        fakePanel = wx.Panel(self, -1, size=(tw, self.GetSize()[1]))
         fakePanel.SetBackgroundColour(TITLE_BACK_COLOUR)
         if CeciliaLib.getVar("systemPlatform") == "win32":
-            self.loadingMsg = GenStaticText(fakePanel, -1, label="loading buffers...    ", pos=(-1, 5))
+            self.loadingMsg = GenStaticText(fakePanel, -1, label="loading buffers...    ", pos=(-1, 7))
         else:
-            self.loadingMsg = wx.StaticText(fakePanel, -1, label="loading buffers...    ", pos=(-1, 5))            
+            self.loadingMsg = wx.StaticText(fakePanel, -1, label="loading buffers...    ", pos=(-1, 7))
+        self.loadingMsg.SetBackgroundColour(TITLE_BACK_COLOUR)
         self.loadingMsg.SetForegroundColour(TITLE_BACK_COLOUR)
         font = self.loadingMsg.GetFont()
         font.SetFaceName(FONT_FACE)
@@ -1241,23 +1188,16 @@ class ToolBar(wx.Panel):
         self.loadingMsg.SetFont(font)
         self.loadingMsg.Refresh()
 
-        if CeciliaLib.getVar("moduleDescription") != '':
-            helpButton = CloseBox(fakePanel, size=(18,18), pos=(25,2), outFunction=self.onShowModuleDescription, 
-                                  label=CeciliaLib.getVar("currentCeciliaFile", unicode=True))
-            helpButton.setBackgroundColour(TITLE_BACK_COLOUR)
-            helpButton.setInsideColour(CONTROLLABEL_BACK_COLOUR)
-            helpButton.setTextMagnify(2)
-
         self.radiotoolbox = RadioToolBox(self, outFunction=[self.toolPointer, self.toolPencil, self.toolZoom, self.toolHand])
         self.palettetoolbox = PaletteToolBox(self)
 
         self.box.Add(ffakePanel, 0)
-        self.box.Add(self.menu, 0, wx.BOTTOM | wx.LEFT, 5)
-        self.box.Add(self.toolbox, 0, wx.BOTTOM | wx.LEFT, 5)
-        self.box.Add(self.convertSlider, 0, wx.TOP | wx.BOTTOM | wx.LEFT, 6)
-        self.box.Add(fakePanel, 0, wx.EXPAND | wx.RIGHT, 20)
-        self.box.Add(self.radiotoolbox, 0, wx.RIGHT, 20)
-        self.box.Add(self.palettetoolbox, 0, wx.RIGHT, 20)
+        self.box.Add(self.menu, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 5)
+        self.box.Add(self.toolbox, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 5)
+        self.box.Add(self.convertSlider, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 5)
+        self.box.Add(fakePanel, 1, wx.EXPAND | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL, 20)
+        self.box.Add(self.radiotoolbox, 0, wx.RIGHT | wx.ALIGN_CENTER_VERTICAL, 20)
+        self.box.Add(self.palettetoolbox, 0, wx.RIGHT | wx.ALIGN_CENTER_VERTICAL, 20)
 
         self.Bind(wx.EVT_CHAR, self.OnKeyDown)
 
@@ -1267,10 +1207,6 @@ class ToolBar(wx.Panel):
         self.Bind(wx.EVT_LEAVE_WINDOW, self.OnLooseFocus)
         fakePanel.Bind(wx.EVT_LEAVE_WINDOW, self.OnLooseFocus)
 
-    def onShowModuleDescription(self):
-        pos = wx.GetMousePosition()
-        pop = TextPopupFrame(self, CeciliaLib.getVar("moduleDescription"), pos=(pos[0]-100,pos[1]+20))
-        
     def OnLooseFocus(self, event):
         win = wx.FindWindowAtPointer()
         if win != None:
@@ -1324,17 +1260,19 @@ class CursorPanel(wx.Panel):
 
     def createBitmap(self):
         w, h = 10, 10
-        maskColour = "#FFFFFF"
+        maskColour = GRAPHER_BACK_COLOUR
         b = wx.EmptyBitmap(w,h)
         dc = wx.MemoryDC(b)
+        gc = wx.GraphicsContext_Create(dc)
         dc.SetBrush(wx.Brush(maskColour))
         dc.SetPen(wx.Pen(maskColour))
         dc.Clear()
         rec = wx.Rect(0, 0, w, h)
         dc.DrawRectangleRect(rec)
-        dc.SetBrush(wx.Brush(GRADIENT_DARK_COLOUR, wx.SOLID))
-        dc.SetPen(wx.Pen(GRADIENT_DARK_COLOUR, 1, wx.SOLID))
-        dc.DrawPolygon([(4, h-1), (0, h-7), (8, h-7)])
+        gc.SetBrush(wx.Brush(GRADIENT_DARK_COLOUR, wx.SOLID))
+        gc.SetPen(wx.Pen(GRADIENT_DARK_COLOUR, 1, wx.SOLID))
+        tri = [(4, h-1), (0, h-7), (8, h-7), (4, h-1)]
+        gc.DrawLines(tri)
         dc.SelectObject(wx.NullBitmap)
         b.SetMaskColour(maskColour)
         return b
@@ -1369,15 +1307,19 @@ class CursorPanel(wx.Panel):
         dc.SetPen(wx.Pen(GRAPHER_BACK_COLOUR))
         dc.SetBrush(wx.Brush(GRAPHER_BACK_COLOUR))
         dc.DrawRectangle(0, 0, w, h)
-        dc.DrawBitmap(self.bitmap, curtime-4, 0, True)
-    
+        dc.DrawBitmap(self.bitmap, curtime-4, 0)
+
     def setTime(self, time):
         self.time = time
         wx.CallAfter(self.Refresh)
 
 class CECGrapher(wx.Panel):
     def __init__(self, parent, id=wx.ID_ANY, pos=(20,20), size=(100, 100)):
-        wx.Panel.__init__(self, parent, id=id, pos=pos, size=size)
+        if CeciliaLib.getVar("systemPlatform") == "win32":
+            BORDER = wx.DOUBLE_BORDER
+        else:
+            BORDER = wx.SIMPLE_BORDER
+        wx.Panel.__init__(self, parent, id=id, pos=pos, size=size, style=BORDER)
         self.parent = parent
         self.SetMinSize((100,100))
         self.SetBackgroundColour(BACKGROUND_COLOUR)
@@ -1389,7 +1331,7 @@ class CECGrapher(wx.Panel):
         self.toolbar = ToolBar(self, tools=['save', 'load', 'reset', 'show'],
                                toolFunctions=[self.OnSave, self.OnLoad, self.onReset, self.onShow])
         mainBox.Add(self.toolbar, 0, wx.EXPAND)
-        
+
         sepLine = Separator(self, size=(200,2), colour=BORDER_COLOUR)
         mainBox.Add(sepLine, 0, wx.EXPAND)
 
@@ -1404,7 +1346,7 @@ class CECGrapher(wx.Panel):
         mainBox.AddGrowableRow(3)
         self.SetSizerAndFit(mainBox)
         self.SetSize(self.GetBestSize())
-        
+
     def getPlotter(self):
         return self.plotter
 
@@ -1428,7 +1370,7 @@ class CECGrapher(wx.Panel):
                 line.setShow(self.showLineState[line.getLabel()])
             self.showLineState = {}
             self.plotter.draw()
-        
+
     def setTotalTime(self, time):
         self.plotter.setTotalTime(time)
 
@@ -1450,10 +1392,11 @@ class CECGrapher(wx.Panel):
                 if line.getName() in names:
                     line.setShow(False)
         self.plotter.draw()
-        
+
     def createLines(self, list):
         for l in list:
             self.createLine(l[0], l[1], l[2], l[3], l[4], l[5], l[6], l[7])
+        self.plotter.draw()
 
     def createLine(self, points, yrange, colour, label, log, name, size, curved):
         self.plotter.createLine(points, yrange, colour, label, log, name, size, curved=curved)
@@ -1461,13 +1404,14 @@ class CECGrapher(wx.Panel):
     def createSliderLines(self, list):
         for l in list:
             self.createSliderLine(l[0], l[1], l[2], l[3], l[4], l[5], l[6], l[7], l[8])
+        self.plotter.draw()
 
     def createSliderLine(self, points, yrange, colour, label, log, name, size, sl, suffix):
         self.plotter.createLine(points, yrange, colour, label, log, name, size, sl, suffix)
 
     def OnSave(self):
         line = self.plotter.getLine(self.plotter.getSelected())
-        dlg = wx.FileDialog(self, message="Save file as ...", defaultDir=os.getcwd(), 
+        dlg = wx.FileDialog(self, message="Save file as ...", defaultDir=CeciliaLib.ensureNFD(os.getcwd()),
                             defaultFile="", style=wx.SAVE)
         if dlg.ShowModal() == wx.ID_OK:
             path = dlg.GetPath()
@@ -1478,8 +1422,9 @@ class CECGrapher(wx.Panel):
 
     def OnLoad(self):
         line = self.plotter.getLine(self.plotter.getSelected())
-        dlg = wx.FileDialog(self, message="Choose a grapher file", defaultDir=CeciliaLib.getVar("grapherLinePath"), 
-            defaultFile="", style=wx.OPEN | wx.CHANGE_DIR)
+        dlg = wx.FileDialog(self, message="Choose a grapher file",
+                defaultDir=CeciliaLib.ensureNFD(CeciliaLib.getVar("grapherLinePath")),
+                defaultFile="", style=wx.OPEN | wx.CHANGE_DIR)
         if dlg.ShowModal() == wx.ID_OK:
             path = dlg.GetPath()
             CeciliaLib.setVar("grapherLinePath", os.path.split(path)[0])
@@ -1503,13 +1448,14 @@ class CECGrapher(wx.Panel):
         dlg.Destroy()
 
     def onReset(self):
+        self.plotter.unselectPoints()
         self.getSelected().reset()
         self.plotter.draw()
 
     def onShow(self, state):
         self.getSelected().setShow(state)
         self.plotter.draw()
-    
+
     def onPopupMenu(self, ind, val):
         self.plotter.setSelected(ind)
         colour = self.getSelected().getMidColour()
@@ -1662,9 +1608,9 @@ class ConvertSlider(PlainSlider):
 def checkFunctionValidity(func, totaltime):
     for i, p in enumerate(func):
         func[i] = (p[0]*totaltime, float(p[1]))
-    if func[0][0] != 0: 
+    if func[0][0] != 0:
         func[0] = (0, func[0][1])
-    if func[-1][0] != totaltime: 
+    if func[-1][0] != totaltime:
         func[-1] = (totaltime, func[-1][1])
     oldX = -1
     for f in func:
@@ -1691,9 +1637,11 @@ def checkLogValidity(linlog, mini, maxi, verbose=False):
             CeciliaLib.showErrorDialog('Error when building interface!', "'min' or 'max' arguments can't be 0 for a logarithmic cgraph. Reset to 'lin'.")
         log = False
     return log
-    
-def buildGrapher(parent, list, totaltime):
-    grapher = CECGrapher(parent, -1)
+
+def getGrapher(parent):
+    return CECGrapher(parent)
+
+def buildGrapher(grapher, list, totaltime):
     grapher.setTotalTime(totaltime)
 
     widgetlist = []
@@ -1732,7 +1680,7 @@ def buildGrapher(parent, list, totaltime):
         log = checkLogValidity(linlog, mini, maxi, True)
         col = widget['col']
         col = checkColourValidity(col)
-        colour = chooseColourFromName(col)
+        colour = CeciliaLib.chooseColourFromName(col)
         labelList.append(label)
         linelist.append([func, (mini, maxi), colour, label, log, name, size, curved])
     if linelist:
@@ -1756,7 +1704,7 @@ def buildGrapher(parent, list, totaltime):
         func = checkFunctionValidity(func, totaltime)
         col = widget['col']
         col = checkColourValidity(col)
-        colour = chooseColourFromName(col)
+        colour = CeciliaLib.chooseColourFromName(col)
         linlog = widget['rel']
         log = checkLogValidity(linlog, mini, maxi)
         for slider in CeciliaLib.getVar("userSliders"):
@@ -1792,9 +1740,9 @@ def buildGrapher(parent, list, totaltime):
             col = widget.get('col', '')
             col = checkColourValidity(col)
             if up:
-                colour = chooseColourFromName("grey")
+                colour = CeciliaLib.chooseColourFromName("grey")
             else:
-                colour = chooseColourFromName(col) 
+                colour = CeciliaLib.chooseColourFromName(col)
             linlog = widget['rel']
             log = checkLogValidity(linlog, mini, maxi)
             for slider in CeciliaLib.getVar("userSliders"):
@@ -1830,9 +1778,9 @@ def buildGrapher(parent, list, totaltime):
             col = widget.get('col', '')
             col = checkColourValidity(col)
             if up:
-                colour = chooseColourFromName("grey")
+                colour = CeciliaLib.chooseColourFromName("grey")
             else:
-                colour = chooseColourFromName(col) 
+                colour = CeciliaLib.chooseColourFromName(col)
             linlog = widget['rel']
             log = checkLogValidity(linlog, mini, maxi)
             for slider in CeciliaLib.getVar("userSliders"):
@@ -1850,7 +1798,7 @@ def buildGrapher(parent, list, totaltime):
     linelist = []
     samplerSliderNames = []
     for i, widget in enumerate(widgetlist3):
-        colour = chooseColour(5, 5)
+        colour = CeciliaLib.chooseColour(5, 5)
         mini = widget.slider.getRange()[0]
         maxi = widget.slider.getRange()[1]
         init = widget.slider.getInit()
@@ -1873,7 +1821,7 @@ def buildGrapher(parent, list, totaltime):
     if len(grapher.plotter.getData()) == 0:
         grapher.createLine([[0, 0], [totaltime, 0]], (0, 1), "#FFFFFF", 'unused', False, 'unused', 8192)
         labelList.append('unused')
-        
+
     for line in grapher.plotter.getData():
         if line.getName() in samplerSliderNames:
             line.setShow(0)
@@ -1885,7 +1833,6 @@ def buildGrapher(parent, list, totaltime):
     grapher.toolbar.setPopupChoice(labelList)
     grapher.plotter.drawCursor(0)
     grapher.plotter._graphCreation = False
-    return grapher
 
 def convert(path, slider, threshold, fromSlider=False, which=None):
     if not fromSlider:
@@ -1908,4 +1855,3 @@ def convert(path, slider, threshold, fromSlider=False, which=None):
     maxval = slider.getMaxValue()
     points = reducePoints(temp, threshold)
     return points
-
