@@ -29,18 +29,13 @@ PADDING = 10
 class PreferenceFrame(wx.Frame):
     def __init__(self, parent):
         style = ( wx.CLIP_CHILDREN | wx.FRAME_NO_TASKBAR | wx.FRAME_SHAPED | wx.NO_BORDER | wx.FRAME_FLOAT_ON_PARENT )
-        wx.Frame.__init__(self, parent, title='', style = style)
+        wx.Frame.__init__(self, parent, style=style)
+        self.SetBackgroundColour(BACKGROUND_COLOUR)
         self.parent = parent
 
-        self.font = wx.Font(MENU_FONT, wx.NORMAL, wx.NORMAL, wx.NORMAL, face=FONT_FACE)
+        self.font = wx.Font(MENU_FONT, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, face=FONT_FACE)
 
-        if CeciliaLib.getVar("systemPlatform")  in ['win32', 'linux2']:
-            self.SetSize((350, 388))
-            
-        if wx.Platform == '__WXGTK__':
-            self.Bind(wx.EVT_WINDOW_CREATE, self.SetRoundShape)
-        else:
-            self.SetRoundShape()
+        self.SetClientSize((350, 390))
 
         panel = wx.Panel(self, -1)
         w, h = self.GetSize()
@@ -63,7 +58,6 @@ class PreferenceFrame(wx.Frame):
         box.AddSpacer(5)
         
         self.panelsBox = wx.BoxSizer(wx.HORIZONTAL)
-        self.panels = []
         pathsPane = self.createPathsPanel(panel)
         audioPane = self.createAudioPanel(panel)
         audioPane.Hide()
@@ -73,31 +67,20 @@ class PreferenceFrame(wx.Frame):
         csoundPane.Hide()
         ceciliaPane = self.createCeciliaPanel(panel)
         ceciliaPane.Hide()
-        self.panels.append(pathsPane)
-        self.panels.append(audioPane)
-        self.panels.append(midiPane)
-        self.panels.append(csoundPane)
-        self.panels.append(ceciliaPane)
+        self.panels = [pathsPane, audioPane, midiPane, csoundPane, ceciliaPane]
         self.currentPane = 0
         self.panelsBox.Add(self.panels[self.currentPane])
         box.Add(self.panelsBox, 0, wx.TOP, 10)
         
-        box.AddSpacer(10)
+        box.AddSpacer(100)
+        box.Add(Separator(panel), 0, wx.EXPAND | wx.BOTTOM, 10)
         closerBox = wx.BoxSizer(wx.HORIZONTAL)
         closer = CloseBox(panel, outFunction=self.onClose)
         closerBox.Add(closer, 0, wx.LEFT, 288)
-        if CeciliaLib.getVar("systemPlatform") == 'win32':
-            box.Add(closerBox, 0, wx.TOP, 85)
-        else:
-            box.Add(closerBox, 0, wx.TOP, 95)
-        box.AddSpacer(10)
-        box.Add(Separator(panel), 0, wx.EXPAND)
+        box.Add(closerBox)
 
         panel.SetSizerAndFit(box)
 
-    def SetRoundShape(self, event=None):
-        self.SetShape(GetRoundShape(350, 388, 1))
-
     def onClose(self, event=None):
         CeciliaLib.writeVarToDisk()
         self.Destroy()
@@ -114,13 +97,12 @@ class PreferenceFrame(wx.Frame):
     def createPathsPanel(self, panel):
         pathsPanel = wx.Panel(panel)
         pathsPanel.SetBackgroundColour(BACKGROUND_COLOUR)
-        gridSizer = wx.FlexGridSizer(2,2,2,5)
 
         # Soundfile Player
         textSfPlayerLabel = wx.StaticText(pathsPanel, -1, 'Soundfile Player :')
         textSfPlayerLabel.SetForegroundColour(PREFS_FOREGROUND)
         textSfPlayerLabel.SetFont(self.font)       
-        self.textSfPlayerPath = wx.TextCtrl(pathsPanel, -1, CeciliaLib.getVar("soundfilePlayer"), size=(274,16), style=wx.TE_PROCESS_ENTER|wx.NO_BORDER)
+        self.textSfPlayerPath = wx.TextCtrl(pathsPanel, -1, CeciliaLib.getVar("soundfilePlayer"), size=(260,16), style=wx.TE_PROCESS_ENTER|wx.NO_BORDER)
         self.textSfPlayerPath.SetFont(self.font)       
         self.textSfPlayerPath.Bind(wx.EVT_TEXT_ENTER, self.handleEditPlayerPath)
         self.textSfPlayerPath.SetForegroundColour(PREFS_FOREGROUND)
@@ -131,7 +113,7 @@ class PreferenceFrame(wx.Frame):
         textSfEditorLabel = wx.StaticText(pathsPanel, -1, 'Soundfile Editor :')
         textSfEditorLabel.SetForegroundColour(PREFS_FOREGROUND)
         textSfEditorLabel.SetFont(self.font)       
-        self.textSfEditorPath = wx.TextCtrl(pathsPanel, -1, CeciliaLib.getVar("soundfileEditor"), size=(274,16), style=wx.TE_PROCESS_ENTER|wx.NO_BORDER)
+        self.textSfEditorPath = wx.TextCtrl(pathsPanel, -1, CeciliaLib.getVar("soundfileEditor"), size=(260,16), style=wx.TE_PROCESS_ENTER|wx.NO_BORDER)
         self.textSfEditorPath.SetFont(self.font)       
         self.textSfEditorPath.Bind(wx.EVT_TEXT_ENTER, self.handleEditEditorPath)
         self.textSfEditorPath.SetForegroundColour(PREFS_FOREGROUND)
@@ -142,7 +124,7 @@ class PreferenceFrame(wx.Frame):
         textTxtEditorLabel = wx.StaticText(pathsPanel, -1, 'Text Editor :')
         textTxtEditorLabel.SetForegroundColour(PREFS_FOREGROUND)
         textTxtEditorLabel.SetFont(self.font)       
-        self.textTxtEditorPath = wx.TextCtrl(pathsPanel, -1, CeciliaLib.getVar("textEditor"), size=(274,16), style=wx.TE_PROCESS_ENTER|wx.NO_BORDER)
+        self.textTxtEditorPath = wx.TextCtrl(pathsPanel, -1, CeciliaLib.getVar("textEditor"), size=(260,16), style=wx.TE_PROCESS_ENTER|wx.NO_BORDER)
         self.textTxtEditorPath.SetFont(self.font)       
         self.textTxtEditorPath.Bind(wx.EVT_TEXT_ENTER, self.handleEditTextEditorPath)
         self.textTxtEditorPath.SetForegroundColour(PREFS_FOREGROUND)
@@ -153,41 +135,61 @@ class PreferenceFrame(wx.Frame):
         textPrefPathLabel = wx.StaticText(pathsPanel, -1, 'Preferred paths :')
         textPrefPathLabel.SetForegroundColour(PREFS_FOREGROUND)
         textPrefPathLabel.SetFont(self.font)       
-        self.textPrefPath = wx.TextCtrl(pathsPanel, -1, CeciliaLib.getVar("prefferedPath"), size=(274,16), style=wx.TE_PROCESS_ENTER|wx.NO_BORDER)
+        self.textPrefPath = wx.TextCtrl(pathsPanel, -1, CeciliaLib.getVar("prefferedPath"), size=(260,16), style=wx.TE_PROCESS_ENTER|wx.NO_BORDER)
         self.textPrefPath.SetFont(self.font)       
         self.textPrefPath.Bind(wx.EVT_TEXT_ENTER, self.handleEditPrefPath)
         self.textPrefPath.SetForegroundColour(PREFS_FOREGROUND)
         self.textPrefPath.SetBackgroundColour(PREFS_PATH_BACKGROUND)
         buttonPrefPath = CloseBox(pathsPanel, outFunction=self.addPrefPath, label='Add...')
 
-        gridSizer.AddMany([ 
-                            (textSfPlayerLabel, 0, wx.EXPAND | wx.LEFT, PADDING),
-                            (wx.StaticText(pathsPanel, -1, ''), 0, wx.EXPAND | wx.LEFT, 5),
-                            (self.textSfPlayerPath, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
-                            (buttonSfPlayerPath, 0, wx.RIGHT, 10),
-                            (textSfEditorLabel, 0, wx.EXPAND | wx.LEFT | wx.TOP, PADDING),
-                            (wx.StaticText(pathsPanel, -1, ''), 0, wx.EXPAND | wx.LEFT, 5),
-                            (self.textSfEditorPath, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
-                            (buttonSfEditorPath, 0, wx.RIGHT, 10),
-                            (textTxtEditorLabel, 0, wx.EXPAND | wx.LEFT | wx.TOP, PADDING),
-                            (wx.StaticText(pathsPanel, -1, ''), 0, wx.EXPAND | wx.LEFT, 5),
-                            (self.textTxtEditorPath, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
-                            (buttonTxtEditorPath, 0, wx.RIGHT, 10),
-                            (textPrefPathLabel, 0, wx.EXPAND | wx.LEFT | wx.TOP, PADDING),
-                            (wx.StaticText(pathsPanel, -1, ''), 0, wx.EXPAND | wx.LEFT, 5),
-                            (self.textPrefPath, 0,  wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
-                            (buttonPrefPath, 0, wx.RIGHT, 10),
-                            ])
-        gridSizer.AddGrowableCol(0, 1)
-        
+#        gridSizer = wx.FlexGridSizer(4,4,2,5)
+#        gridSizer.AddMany([ 
+#                            (textSfPlayerLabel, 0, wx.EXPAND | wx.LEFT, PADDING),
+#                            (wx.StaticText(pathsPanel, -1, ''), 0, wx.EXPAND | wx.LEFT, 5),
+#                            (self.textSfPlayerPath, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
+#                            (buttonSfPlayerPath, 0, wx.RIGHT, 10),
+#                            (textSfEditorLabel, 0, wx.EXPAND | wx.LEFT | wx.TOP, PADDING),
+#                            (wx.StaticText(pathsPanel, -1, ''), 0, wx.EXPAND | wx.LEFT, 5),
+#                            (self.textSfEditorPath, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
+#                            (buttonSfEditorPath, 0, wx.RIGHT, 10),
+#                            (textTxtEditorLabel, 0, wx.EXPAND | wx.LEFT | wx.TOP, PADDING),
+#                            (wx.StaticText(pathsPanel, -1, ''), 0, wx.EXPAND | wx.LEFT, 5),
+#                            (self.textTxtEditorPath, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
+#                            (buttonTxtEditorPath, 0, wx.RIGHT, 10),
+#                            (textPrefPathLabel, 0, wx.EXPAND | wx.LEFT | wx.TOP, PADDING),
+#                            (wx.StaticText(pathsPanel, -1, ''), 0, wx.EXPAND | wx.LEFT, 5),
+#                            (self.textPrefPath, 0,  wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
+#                            (buttonPrefPath, 0, wx.RIGHT, 10),
+#                            ])
+#        gridSizer.AddGrowableCol(0, 1)
+
+        # item, pos, span, flag, border
+        gridSizer = wx.GridBagSizer(2, PADDING)
+        gridSizer.Add(textSfPlayerLabel, pos=(0,0), span=(1,1), flag=wx.ALIGN_CENTER_VERTICAL|wx.LEFT, border=5)
+        gridSizer.Add(self.textSfPlayerPath, pos=(1,0), span=(1,2), flag=wx.ALIGN_CENTER_VERTICAL|wx.BOTTOM|wx.LEFT, border=5)        
+        gridSizer.Add(buttonSfPlayerPath, pos=(1,2), span=(1,1), flag=wx.ALIGN_CENTER_VERTICAL|wx.BOTTOM, border=5)
+
+        gridSizer.Add(textSfEditorLabel, pos=(2,0), span=(1,1), flag=wx.ALIGN_CENTER_VERTICAL|wx.LEFT, border=5)
+        gridSizer.Add(self.textSfEditorPath, pos=(3,0), span=(1,2), flag=wx.ALIGN_CENTER_VERTICAL|wx.BOTTOM|wx.LEFT, border=5)
+        gridSizer.Add(buttonSfEditorPath, pos=(3,2), span=(1,1), flag=wx.ALIGN_CENTER_VERTICAL|wx.BOTTOM, border=5)
+
+        gridSizer.Add(textTxtEditorLabel, pos=(4,0), span=(1,1), flag=wx.ALIGN_CENTER_VERTICAL|wx.LEFT, border=5)
+        gridSizer.Add(self.textTxtEditorPath, pos=(5,0), span=(1,2), flag=wx.ALIGN_CENTER_VERTICAL|wx.BOTTOM|wx.LEFT, border=5)
+        gridSizer.Add(buttonTxtEditorPath, pos=(5,2), span=(1,1), flag=wx.ALIGN_CENTER_VERTICAL|wx.BOTTOM, border=5)
+
+        gridSizer.Add(textPrefPathLabel, pos=(6,0), span=(1,1), flag=wx.ALIGN_CENTER_VERTICAL|wx.LEFT, border=5)
+        gridSizer.Add(self.textPrefPath, pos=(7,0), span=(1,2), flag=wx.ALIGN_CENTER_VERTICAL|wx.BOTTOM|wx.LEFT, border=5)
+        gridSizer.Add(buttonPrefPath, pos=(7,2), span=(1,1), flag=wx.ALIGN_CENTER_VERTICAL|wx.BOTTOM, border=5)
+
+        pathsPanel.SetSizerAndFit(gridSizer)
+
         self.textSfPlayerPath.Navigate()
-        panel.SetSizerAndFit(gridSizer)
         return pathsPanel
 
     def createCeciliaPanel(self, panel):
         ceciliaPanel = wx.Panel(panel)
         ceciliaPanel.SetBackgroundColour(BACKGROUND_COLOUR)
-        gridSizer = wx.FlexGridSizer(4,3,10,3)
+        gridSizer = wx.FlexGridSizer(5,3,10,3)
 
         textTotalTime = wx.StaticText(ceciliaPanel, 0, 'Total time default (sec) :')
         textTotalTime.SetForegroundColour(PREFS_FOREGROUND)
@@ -314,7 +316,7 @@ class PreferenceFrame(wx.Frame):
         self.autoMidiToggle = Toggle(midiParamPanel, CeciliaLib.getVar("automaticMidiBinding"), outFunction=self.enableAutomaticBinding)
         gridSizer2.AddMany([ 
                             (textAutoBinding, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
-                            (self.autoMidiToggle, 1, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 163),
+                            (self.autoMidiToggle, 1, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 174),
                             ])
 
         gridSizer1.AddGrowableCol(1, 1)
@@ -363,7 +365,7 @@ class PreferenceFrame(wx.Frame):
         self.driverPanels['jack'] = jackPane
         self.driverBox.Add(self.driverPanels[self.driverCurrentPane])
         
-        gridSizer3 = wx.FlexGridSizer(5, 3, 5, 5)
+        gridSizer3 = wx.FlexGridSizer(6, 3, 5, 5)
 
         # Sample precision
         textSamplePrecision = wx.StaticText(audioParamPanel, 0, 'Sample Precision :')
@@ -410,7 +412,7 @@ class PreferenceFrame(wx.Frame):
 
         gridSizer3.AddMany([ 
                             (textSamplePrecision, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
-                            (wx.StaticText(audioParamPanel, -1, '', size=(89,-1)), 1, wx.EXPAND),
+                            (wx.StaticText(audioParamPanel, -1, '', size=(98,-1)), 1, wx.EXPAND),
                             (self.choiceSamplePrecision, 0, wx.ALIGN_CENTER_VERTICAL),
                             (textBufferSize, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
                             (wx.StaticText(audioParamPanel, -1, ''), 1, wx.EXPAND),
@@ -459,11 +461,11 @@ class PreferenceFrame(wx.Frame):
             else:
                 initInput = ''
         self.midiChoiceInput = CustomMenu(portmidiPanel, choice=availableMidiIns, init=initInput, 
-                                          size=(168,20), outFunction=self.changeMidiInput, maxChar=25)
+                                          size=(168,20), outFunction=self.changeMidiInput)
 
         gridSizer.AddMany([ 
                             (textIn, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
-                             (wx.StaticText(portmidiPanel, -1, '', size=(72,-1)), 1, wx.EXPAND),
+                             (wx.StaticText(portmidiPanel, -1, '', size=(75,-1)), 1, wx.EXPAND),
                             (self.midiChoiceInput, 0, wx.ALIGN_CENTER_VERTICAL),
                             ])
                             
@@ -491,7 +493,7 @@ class PreferenceFrame(wx.Frame):
             else:
                 initInput = ''
         self.choiceInput = CustomMenu(portaudioPanel, choice=availableAudioIns, init=initInput, 
-                                      size=(168,20), outFunction=self.changeAudioInput, maxChar=25)
+                                      size=(168,20), outFunction=self.changeAudioInput)
         if CeciliaLib.getVar("enableAudioInput") == 0:
             initInputState = 0
         else:
@@ -513,14 +515,14 @@ class PreferenceFrame(wx.Frame):
             else:
                 initOutput = ''
         self.choiceOutput = CustomMenu(portaudioPanel, choice=availableAudioOuts, init=initOutput, 
-                                       size=(168,20), outFunction=self.changeAudioOutput, maxChar=25)
+                                       size=(168,20), outFunction=self.changeAudioOutput)
         
         gridSizer.AddMany([ 
                             (textIn, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
-                            (self.inputToggle, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 43),
+                            (self.inputToggle, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 45),
                             (self.choiceInput, 0, wx.ALIGN_CENTER_VERTICAL),
                             (textOut, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, PADDING),
-                            (wx.StaticText(portaudioPanel, -1, '', size=(63,-1)), 1, wx.EXPAND),
+                            (wx.StaticText(portaudioPanel, -1, '', size=(65,-1)), 1, wx.EXPAND),
                             (self.choiceOutput, 0, wx.ALIGN_CENTER_VERTICAL),
                             ])
         gridSizer.AddGrowableCol(1, 1)
@@ -612,7 +614,7 @@ class PreferenceFrame(wx.Frame):
 
         path = ''
         dlg = wx.DirDialog(self, message="Choose a folder...",
-                                 defaultPath=os.path.expanduser('~'))
+                                 defaultPath=CeciliaLib.ensureNFD(os.path.expanduser('~')))
 
         if dlg.ShowModal() == wx.ID_OK:
             path = dlg.GetPath()   
