@@ -24,21 +24,25 @@ import CeciliaLib
 from Widgets import *
 
 class CECPreset(wx.Panel):
-    def __init__(self, parent, id=-1, size=(-1,-1), style = wx.NO_BORDER):
+    if CeciliaLib.getVar("systemPlatform") == "win32":
+        BORDER = wx.DOUBLE_BORDER
+    else:
+        BORDER = wx.SIMPLE_BORDER
+    def __init__(self, parent, id=-1, size=(-1,-1), style = BORDER):
         wx.Panel.__init__(self, parent, id, size=size, style=style)
         self.SetBackgroundColour(BACKGROUND_COLOUR)
         self.parent = parent
         
         self.currentPreset = 'init'
         
-        mainSizer = wx.FlexGridSizer(2,1)
+        mainSizer = wx.FlexGridSizer(0,1)
         mainSizer.AddSpacer((10,1))
         
         presetTextPanel = wx.Panel(self, -1, style=wx.NO_BORDER)
         presetTextPanel.SetBackgroundColour(TITLE_BACK_COLOUR)
         presetTextSizer = wx.FlexGridSizer(1,1)
         presetText = wx.StaticText(presetTextPanel, -1, 'PRESETS')
-        presetText.SetFont(wx.Font(SECTION_TITLE_FONT, wx.NORMAL, wx.NORMAL, wx.BOLD, face=FONT_FACE))
+        presetText.SetFont(wx.Font(SECTION_TITLE_FONT, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_BOLD, face=FONT_FACE))
         presetText.SetBackgroundColour(TITLE_BACK_COLOUR)
         presetText.SetForegroundColour(SECTION_TITLE_COLOUR)
         presetTextSizer.Add(presetText, 0, wx.ALIGN_RIGHT | wx.ALL, 3)
@@ -58,7 +62,8 @@ class CECPreset(wx.Panel):
         saveTool = ToolBox(self, tools=['save', 'delete'], outFunction = [self.onSavePreset, self.onDeletePreset])
         lineSizer.Add(saveTool, 0, wx.ALIGN_RIGHT | wx.ALIGN_CENTER_VERTICAL | wx.RIGHT, 2)
         
-        mainSizer.Add(lineSizer, 0, wx.ALIGN_CENTER | wx.ALL, 7)
+        mainSizer.Add(lineSizer, 0, wx.EXPAND | wx.ALIGN_CENTER | wx.ALL, 7)
+        
         mainSizer.AddGrowableCol(0)
         self.SetSizer(mainSizer)
 
