@@ -25,6 +25,10 @@ import CeciliaLib
 from constants import *
 from Widgets import *
 
+### TODO:
+# When an OSC controler is defined for a slider, the interface initialization gives this error:
+# TypeError: in method 'Window_Refresh', expected argument 1 of type 'wxWindow *'
+
 def interpFloat(t, v1, v2):
     "interpolator for a single value; interprets t in [0-1] between v1 and v2"
     return (v2-v1)*t + v1
@@ -69,6 +73,11 @@ class PlayRecButtons(wx.Panel):
         self.play = 0
         self.rec = False
 
+        if CeciliaLib.getVar("systemPlatform") == "win32":
+            self.dcref = wx.BufferedPaintDC
+        else:
+            self.dcref = wx.PaintDC
+
     def setOverWait(self, which):
         if which == 0:
             self.playOverWait = False
@@ -143,7 +152,8 @@ class PlayRecButtons(wx.Panel):
 
     def OnPaint(self, evt):
         w,h = self.GetSize()
-        dc = wx.AutoBufferedPaintDC(self)
+        dc = self.dcref(self)
+        gc = wx.GraphicsContext_Create(dc)
 
         dc.SetBrush(wx.Brush(BACKGROUND_COLOUR, wx.SOLID))
         dc.Clear()
@@ -154,9 +164,10 @@ class PlayRecButtons(wx.Panel):
         # Draw triangle
         if self.playOver: playColour = SLIDER_PLAY_COLOUR_OVER
         else: playColour = self.playColour
-        dc.SetPen(wx.Pen(playColour, width=1, style=wx.SOLID))  
-        dc.SetBrush(wx.Brush(playColour, wx.SOLID))
-        dc.DrawPolygon([wx.Point(14,h/2), wx.Point(9,4), wx.Point(9,h-4)])
+        gc.SetPen(wx.Pen(playColour, width=1, style=wx.SOLID))  
+        gc.SetBrush(wx.Brush(playColour, wx.SOLID))
+        tri = [(14,h/2), (9,4), (9,h-4), (14,h/2)]
+        gc.DrawLines(tri)
 
         dc.SetPen(wx.Pen('#333333', width=1, style=wx.SOLID))  
         dc.DrawLine(w/2,4,w/2,h-4)
@@ -164,9 +175,9 @@ class PlayRecButtons(wx.Panel):
         # Draw circle
         if self.recOver: recColour = SLIDER_REC_COLOUR_OVER
         else: recColour = self.recColour
-        dc.SetPen(wx.Pen(recColour, width=1, style=wx.SOLID))  
-        dc.SetBrush(wx.Brush(recColour, wx.SOLID))
-        dc.DrawCircle(w/4+w/2, h/2, 4)
+        gc.SetPen(wx.Pen(recColour, width=1, style=wx.SOLID))  
+        gc.SetBrush(wx.Brush(recColour, wx.SOLID))
+        gc.DrawEllipse(w/4+w/2-4, h/2-4, 8, 8)
 
         evt.Skip()
 
@@ -258,7 +269,7 @@ class Slider(wx.Panel):
     def setFillColour(self, col1, col2):
         self.fillcolor = col1
         self.knobcolor = col2
-        self.createSliderBitmap()
+        self.createBackgroundBitmap()
         self.createKnobBitmap()
 
     def SetRange(self, minvalue, maxvalue):
@@ -291,9 +302,9 @@ class Slider(wx.Panel):
             
     def OnResize(self, evt):
         self.createSliderBitmap()
+        self.createKnobMaskBitmap()
         self.createKnobBitmap()
         self.createBackgroundBitmap()
-        self.createKnobMaskBitmap()
         self.clampPos()    
         wx.CallAfter(self.Refresh)
 
@@ -318,18 +329,18 @@ class HSlider(Slider):
             self.knobSize = 28
             self.knobHalfSize = 14
         self.sliderHeight = 14
-        self.createSliderBitmap()
         self.createKnobMaskBitmap()
-        self.createBackgroundBitmap()
+        self.createSliderBitmap()
         self.createKnobBitmap()
+        self.createBackgroundBitmap()
         self.value = 0
-        if init != None: self.SetValue(init)
-        else: self.SetValue(minvalue)
+        if init != None: self._setValue(init)
+        else: self._setValue(minvalue)
         self.clampPos()
         self.midictl = ''
         self.midiLearn = False
         self.openSndCtrl = ''
-        self.font = wx.Font(LABEL_FONT-2, wx.NORMAL, wx.ITALIC, wx.LIGHT, face=FONT_FACE)
+        self.font = wx.Font(LABEL_FONT-2, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_ITALIC, wx.FONTWEIGHT_LIGHT, face=FONT_FACE)
 
         self.mario = 0
         self.useMario = False
@@ -386,9 +397,9 @@ class HSlider(Slider):
 
     def setOpenSndCtrl(self, str):
         self.openSndCtrl = str
-        self.OnResize(None)
+        #self.OnResize(None)
 
-    def SetValue(self, value):
+    def _setValue(self, value):
         self.lastvalue = self.value
         value = clamp(value, self.minvalue, self.maxvalue)
         if self.log:
@@ -399,7 +410,12 @@ class HSlider(Slider):
             self.value = interpFloat(t, self.minvalue, self.maxvalue)
         if self.myType == IntType:
             self.value = int(self.value)
-        self.OnResize(None)
+        self.clampPos()    
+
+    def SetValue(self, value):
+        self._setValue(value)
+        #self.OnResize(None)
+        wx.CallAfter(self.Refresh)
 
     def GetValue(self):
         if self.log:
@@ -431,7 +447,7 @@ class HSlider(Slider):
             self.mario += 1
             
         if self.midiLearn:    
-            dc.SetFont(wx.Font(LABEL_FONT-1, wx.NORMAL, wx.ITALIC, wx.LIGHT, face=FONT_FACE))
+            dc.SetFont(wx.Font(LABEL_FONT-1, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_ITALIC, wx.FONTWEIGHT_LIGHT, face=FONT_FACE))
             dc.DrawLabel("Move a MIDI controller...", wx.Rect(5, 0, 50, h), wx.ALIGN_CENTER_VERTICAL)
         elif self.openSndCtrl:
             dc.DrawLabel(self.openSndCtrl, wx.Rect(5, 0, w, h), wx.ALIGN_CENTER_VERTICAL)            
@@ -488,7 +504,7 @@ class CECSlider:
         self.buttons.SetToolTip(CECTooltip(TT_SLIDER_PLAY + '\n\n' + TT_SLIDER_RECORD))
 
     def setFillColour(self, col1, col2, col3):
-        self.slider.setFillColour(col3, col2)
+        self.slider.setFillColour(col1, col2)
         self.label.setBackColour(col1)
         self.entryUnit.setBackColour(col1)
 
@@ -542,11 +558,18 @@ class CECSlider:
         self.sendValue(value)
 
     def writeToEntry(self, value):
+        # valeurs proche de 0 a 5 decimales...
         if self.slider.myType == FloatType:
             if value >= 10000:
                 self.entryUnit.setValue(float('%5.2f' % value))
             elif value >= 1000:
                 self.entryUnit.setValue(float('%5.3f' % value))
+            elif value >= 10:
+                self.entryUnit.setValue(float('%5.5f' % value))
+            elif value >= 0:
+                self.entryUnit.setValue(float('%5.6f' % value))
+            elif value >= -100:
+                self.entryUnit.setValue(float('%5.5f' % value))
             elif value >= -1000:
                 self.entryUnit.setValue(float('%5.4f' % value))
             elif value >= -10000:
@@ -600,11 +623,9 @@ class CECSlider:
             self.setMidiChannel(values[3])
         self.setMidiCtl(values[2])
         if len(values) >= 5:
-            if values[4] != None:
-                self.setOpenSndCtrl("%d:%s" % (values[4][0], values[4][1]))
+            self.setOpenSndCtrl(values[4])
         if len(values) >= 6:
-            if values[5] != None:
-                self.setOSCOut("%s:%d:%s" % (values[5][0], values[5][1], values[5][2]))
+            self.setOSCOut(values[5])
 
     def getPath(self):
         return self.path
@@ -619,7 +640,7 @@ class CECSlider:
             self.slider.setMidiCtl("%d:%d" % (self.midictl, self.midichan))
             self.openSndCtrl = None
             self.slider.setOpenSndCtrl('')
-        self.slider.Refresh()
+        wx.CallAfter(self.slider.Refresh)
         
     def getMidiCtl(self):
         return self.midictl
@@ -637,28 +658,28 @@ class CECSlider:
             return False
 
     def setOpenSndCtrl(self, value):
-        if value != None:
-            if value == "":
-                self.openSndCtrl = None
-                self.slider.setOpenSndCtrl("")
-            else:
-                sep = value.split(":")
-                port = int(sep[0].strip())
-                address = str(sep[1].strip())
-                self.openSndCtrl = (port, address)
-                self.slider.setOpenSndCtrl("%d:%s" % (port, address))
-                self.setMidiCtl(None)
+        if value == None or value == "":
+            self.openSndCtrl = None
+            self.slider.setOpenSndCtrl("")
+        else:
+            msg = "%d:%s" % (value[0], value[1])
+            sep = msg.split(":")
+            port = int(sep[0].strip())
+            address = str(sep[1].strip())
+            self.openSndCtrl = (port, address)
+            self.slider.setOpenSndCtrl("%d:%s" % (port, address))
+            self.setMidiCtl(None)
 
     def setOSCOut(self, value):
-        if value != None:
-            if value == "":
-                self.OSCOut = None
-            else:
-                sep = value.split(":")
-                host = str(sep[0].strip())
-                port = int(sep[1].strip())
-                address = str(sep[2].strip())
-                self.OSCOut = (host, port, address)
+        if value == None or value == "":
+            self.OSCOut = None
+        else:
+            msg = "%s:%d:%s" % (value[0], value[1], value[2])
+            sep = msg.split(":")
+            host = str(sep[0].strip())
+            port = int(sep[1].strip())
+            address = str(sep[2].strip())
+            self.OSCOut = (host, port, address)
 
     def getOpenSndCtrl(self):
         return self.openSndCtrl
@@ -772,7 +793,7 @@ class RangeSlider(wx.Panel):
         self.fillcolor = col1
         self.knobcolor = col2
         self.handlecolor = wx.Colour(self.knobcolor[0]*0.35, self.knobcolor[1]*0.35, self.knobcolor[2]*0.35)
-        self.createSliderBitmap()
+        self.createBackgroundBitmap()
 
     def SetRange(self, minvalue, maxvalue):   
         self.minvalue = minvalue
@@ -866,7 +887,7 @@ class HRangeSlider(RangeSlider):
         self.openSndCtrl1 = ''
         self.openSndCtrl2 = ''
         self.midiLearn = False
-        self.font = wx.Font(LABEL_FONT-2, wx.NORMAL, wx.ITALIC, wx.LIGHT, face=FONT_FACE)
+        self.font = wx.Font(LABEL_FONT-2, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_ITALIC, wx.FONTWEIGHT_LIGHT, face=FONT_FACE)
 
     def setSliderHeight(self, height):
         self.sliderHeight = height
@@ -975,7 +996,7 @@ class HRangeSlider(RangeSlider):
         dc.DrawRoundedRectangleRect(rec, 3)
 
         if self.midiLearn:
-            dc.SetFont(wx.Font(LABEL_FONT-1, wx.NORMAL, wx.ITALIC, wx.LIGHT, face=FONT_FACE))
+            dc.SetFont(wx.Font(LABEL_FONT-1, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_ITALIC, wx.FONTWEIGHT_LIGHT, face=FONT_FACE))
             dc.DrawLabel("Move 2 MIDI controllers...", wx.Rect(5, 0, 50, h), wx.ALIGN_CENTER_VERTICAL)
         elif self.openSndCtrl1 or self.openSndCtrl2:
             if self.openSndCtrl1:
@@ -1098,17 +1119,17 @@ class CECRange:
                 elif value >= 1000:
                     val = float('%5.1f' % value)
                 elif value >= 100:
-                    val = float('%5.2f' % value)
+                    val = float('%5.1f' % value)
                 elif value >= 10:
-                    val = float('%5.3f' % value)
-                elif value >= -100:
-                    val = float('%5.3f' % value)
-                elif value >= -1000:
                     val = float('%5.2f' % value)
+                elif value >= -100:
+                    val = float('%5.2f' % value)
+                elif value >= -1000:
+                    val = float('%5.1f' % value)
                 elif value >= -10000:
                     val = float('%5.1f' % value)
                 else:
-                    val = float('%5.2f' % value)
+                    val = float('%5.0f' % value)
                 tmp.append(val)
         else:
             tmp = [i for i in values]
@@ -1191,7 +1212,7 @@ class CECRange:
             self.openSndCtrl = None
             self.slider.setOpenSndCtrl('', "left")
             self.slider.setOpenSndCtrl('', "right")
-        self.slider.Refresh()
+        wx.CallAfter(self.slider.Refresh)
 
     def getMidiCtl(self):
         return self.midictl
@@ -1481,7 +1502,7 @@ class HSplitterSlider(SplitterSlider):
         self.midictl1 = ''
         self.midictl2 = ''
         self.midiLearn = False
-        self.font = wx.Font(SPLITTER_FONT, wx.NORMAL, wx.ITALIC, wx.LIGHT, face=FONT_FACE)
+        self.font = wx.Font(SPLITTER_FONT, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_ITALIC, wx.FONTWEIGHT_LIGHT, face=FONT_FACE)
 
     def setSliderHeight(self, height):
         self.sliderHeight = height
@@ -1580,7 +1601,7 @@ class HSplitterSlider(SplitterSlider):
             dc.DrawLabel(self.midictl1, wx.Rect(10, 0, 30, h), wx.ALIGN_CENTER_VERTICAL)
             dc.DrawLabel(self.midictl2, wx.Rect(w-20, 0, 20, h), wx.ALIGN_CENTER_VERTICAL)
         else:
-            dc.SetFont(wx.Font(LABEL_FONT-1, wx.NORMAL, wx.ITALIC, wx.LIGHT, face=FONT_FACE))
+            dc.SetFont(wx.Font(LABEL_FONT-1, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_ITALIC, wx.FONTWEIGHT_LIGHT, face=FONT_FACE))
             dc.DrawLabel("Move 2 MIDI controllers...", wx.Rect(5, 0, 50, h), wx.ALIGN_CENTER_VERTICAL)
 
         # Send value
@@ -1786,6 +1807,7 @@ class CECSplitter:
 
 def buildHorizontalSlidersBox(parent, list):
     mainBox = wx.BoxSizer(wx.VERTICAL)
+    outBox = wx.BoxSizer(wx.VERTICAL)
     sliders = []
     halfcount = 0
     for widget in list:
@@ -1849,4 +1871,5 @@ def buildHorizontalSlidersBox(parent, list):
                 halfcount += 1  
             sliders.append(sl)
 
-    return mainBox, sliders
+    outBox.Add(mainBox, 0, wx.ALL|wx.EXPAND, 3)
+    return outBox, sliders
