@@ -1,13 +1,13 @@
 rm -rf build dist
 
-export DMG_DIR="Cecilia5 5.0.9"
-export DMG_NAME="Cecilia5_5.0.9.dmg"
+export DMG_DIR="Cecilia5 5.2.1"
+export DMG_NAME="Cecilia5_5.2.1.dmg"
 
 if [ -f setup.py ]; then
     mv setup.py setup_back.py;
 fi
 
-py2applet --make-setup Cecilia5.py Resources/*
+py2applet --make-setup --argv-emulation=0 Cecilia5.py Resources/*
 python setup.py py2app --plist=scripts/info.plist
 rm -f setup.py
 rm -rf build
@@ -15,7 +15,7 @@ mv dist Cecilia5_OSX
 
 if cd Cecilia5_OSX;
 then
-    find . -name .svn -depth -exec rm -rf {} \
+    find . -name .git -depth -exec rm -rf {} \
     find . -name *.pyc -depth -exec rm -f {} \
     find . -name .* -depth -exec rm -f {} \;
 else
@@ -26,18 +26,14 @@ fi
 rm Cecilia5.app/Contents/Resources/Cecilia5.ico
 rm Cecilia5.app/Contents/Resources/CeciliaFileIcon5.ico
 
-ditto --rsrc --arch i386 Cecilia5.app Cecilia5-i386.app
+# keep only 64-bit arch
+ditto --rsrc --arch x86_64 Cecilia5.app Cecilia5-x86_64.app
 rm -rf Cecilia5.app
-mv Cecilia5-i386.app Cecilia5.app
+mv Cecilia5-x86_64.app Cecilia5.app
 
 cd ..
 cp -R Cecilia5_OSX/Cecilia5.app .
 
-# Fixed wrong path in Info.plist
-cd Cecilia5.app/Contents
-awk '{gsub("Library/Frameworks/Python.framework/Versions/2.6/Resources/Python.app/Contents/MacOS/Python", "@executable_path/../Frameworks/Python.framework/Versions/2.6/Python")}1' Info.plist > Info.plist_tmp && mv Info.plist_tmp Info.plist
-
-cd ../..
 echo "assembling DMG..."
 mkdir "$DMG_DIR"
 cd "$DMG_DIR"
